# Copyright (C) 2013-2023, Hiroshi Izumi (izumi.h@aist.go.jp)
# This code is part of the Biopython distribution and governed by its
# license.  Please see the LICENSE file that should have been included
# as part of this package.

from __future__ import print_function
#from Bio._py3k import basestring

import warnings

import Bio.PDB
import os
from difflib import *
import gzip
from mimetypes import guess_type

#from Bio.Alphabet import generic_protein
#from Bio.Data import SCOPData
from Bio.Seq import Seq
from Bio.PDB.PDBExceptions import PDBException
#from Bio.PDB.PDBParser import PDBParser
#from Bio.PDB.Vector import calc_dihedral, calc_angle
from Bio.PDB.vectors import calc_dihedral, calc_angle

def _open(file):
    encoding = guess_type(file)[1]  # uses file extension
    if encoding == "gzip":
        return gzip.open(file, mode='rt')
    else:
        return open(file)

def conf_code_al(self):
    code_letter ={'A':'4c', 'B':'2a', 'C':'2c', 'D':'5a', 'E':'5c', \
             'F':'1a', 'G':'1c', 'H':'6a', 'I':'6c', 'J':'3a', 'K':'3c', \
             'L':'4a'}
    # ConfCode
    pi=3.141592653589793115997963468544
    pi1=pi/6
    pi2=2*pi/6
    pi3=3*pi/6
    pi4=4*pi/6
    pi5=5*pi/6
    mpi=-1*pi
    mpi1=-1*pi/6
    mpi2=-2*pi/6
    mpi3=-3*pi/6
    mpi4=-4*pi/6
    mpi5=-5*pi/6
    cc_arith = ""
    cc = ""
    # Decision of ConfCode
    if self == None:
        cc_arith = None
        cc = None    
    elif self>=0 and self<pi1:
        cc_arith = 'A'
        cc = "%s" % (code_letter[cc_arith])
    elif self>=pi1 and self<pi2:
        cc_arith = 'B'
        cc = "%s" % (code_letter[cc_arith])
    elif self>=pi2 and self<pi3:
        cc_arith = 'C'
        cc = "%s" % (code_letter[cc_arith])
    elif self>=pi3 and self<pi4:
        cc_arith = 'D'
        cc = "%s" % (code_letter[cc_arith])
    elif self>=pi4 and self<pi5:
        cc_arith = 'E'
        cc = "%s" % (code_letter[cc_arith])
    elif self>=pi5 and self<=pi:
        cc_arith = 'F'
        cc = "%s" % (code_letter[cc_arith])
    elif self>mpi and self<=mpi5:
        cc_arith = 'G'
        cc = "%s" % (code_letter[cc_arith])
    elif self>mpi5 and self<=mpi4:
        cc_arith = 'H'
        cc = "%s" % (code_letter[cc_arith])
    elif self>mpi4 and self<=mpi3:
        cc_arith = 'I'
        cc = "%s" % (code_letter[cc_arith])
    elif self>mpi3 and self<=mpi2:
        cc_arith = 'J'
        cc = "%s" % (code_letter[cc_arith])
    elif self>mpi2 and self<=mpi1:
        cc_arith = 'K'
        cc = "%s" % (code_letter[cc_arith])
    elif self>mpi1 and self<0:
        cc_arith = 'L'
        cc = "%s" % (code_letter[cc_arith])
    else:
        cc_arith = None
        cc = None
    return cc

def _test_homology_al(self1, self2):
    """Return 1 if structural homology between self1 snd self2 exists."""
    code_list =['4c', '2a', '2c', '5a', '5c', \
                '1a', '1c', '6a', '6c', '3a', '3c', \
                '4a']
    code_3letter_1 ={'A':'LAB', 'B':'ABC', 'C':'BCD', \
                    'D':'CDE', 'E':'DEF', 'F':'EFG', \
                    'G':'FGH', 'H':'GHI', 'I':'HIJ', \
                    'J':'IJK', 'K':'JKL', 'L':'KLA'}
    code_3letter_2 ={'4c':'A', '2a':'B', '2c':'C', '5a':'D', '5c':'E', \
                    '1a':'F', '1c':'G', '6a':'H', '6c':'I', '3a':'J', '3c':'K', \
                    '4a':'L'}
    if self1 in code_list:
        code1 = "%s" % (code_3letter_2[self1])
    else:
        return 0
    code3_1 = code_3letter_1[code1]
    lcode3_1 = list(code3_1)
    if self2 in code_list:
        code2 = "%s" % (code_3letter_2[self2])
    else:
        return 0
    code3_2 = code_3letter_1[code2]
    lcode3_2 = list(code3_2)
    for code_index, code in enumerate(lcode3_1) :
        if code in lcode3_2 :
            return 1
        else:
            if code_index == 2 :
                return 0
            else:
                continue

flist = os.listdir("C:/SSCRview/PDB_MMCIF_GZ")

for i, pdb_file_gz in enumerate(flist):
    os.chdir("C:/SSCRview/PDB_MMCIF_GZ")
    pdb_file = _open(pdb_file_gz)
    for model in Bio.PDB.FastMMCIFParser().get_structure("RNA", pdb_file) :
        for chain in model :
            full_id=model.get_full_id()
            #mname = pdb_file[-8:-4]
            mname = pdb_file_gz[:-7]
            fname = "C:/SSCRview/SSCR_data/%s_Model_%s_Chain_%s_SSCR.txt" % (str(mname), str(model.id), str(chain.id))
            c4dp = []
            c3dp = []
            o3dp = []
            residue_nump = 0
            for residue_index, residue in enumerate(chain) :
                residue_id = residue.id
                residue_num = residue_id[1]
                residue_name = residue.resname
                #print (residue_name)
                if residue_name == "A" or residue_name == "G" or residue_name == "C" or residue_name == "U" :
                    if residue_index == 0:
                        ppl=[]
                        fc = open(str(fname), 'w')
                        fc.write('')
                        mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                        mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                        mname3 = "length %i " % (len(residue))
                        fc.write(str(mname1))
                        fc.write('\n')
                        fc.close()
                        residue_nump = residue_num
                        # A
                        if residue_name == "A" :
                            for atom_index, atom in enumerate(residue) :
                                atom_id = atom.id
                                res = atom
                                try:
                                    if atom_id == "P" :
                                        p = atom.get_vector()
                                    elif atom_id == "O5'" :
                                        o5d = atom.get_vector()
                                    elif atom_id == "C5'" :
                                        c5d = atom.get_vector()
                                    elif atom_id == "C4'" :
                                        c4d = atom.get_vector()
                                    elif atom_id == "O4'" :
                                        o4d = atom.get_vector()
                                    elif atom_id == "C3'" :
                                        c3d = atom.get_vector()
                                    elif atom_id == "O3'" :
                                        o3d = atom.get_vector()
                                    elif atom_id == "C2'" :
                                        c2d = atom.get_vector()
                                    elif atom_id == "O2'" :
                                        o2d = atom.get_vector()
                                    elif atom_id == "C1'" :
                                        c1d = atom.get_vector()
                                    elif atom_id == "OH" :
                                        oh = atom.get_vector()
                                    elif atom_id == "N9" :
                                        n9 = atom.get_vector()
                                    elif atom_id == "C8" :
                                        c8 = atom.get_vector()
                                    elif atom_id == "C6" :
                                        c6 = atom.get_vector()
                                    elif atom_id == "N6" :
                                        n6 = atom.get_vector()
                                    elif atom_id == "N1" :
                                        n1 = atom.get_vector()
                                    elif atom_id == "NH" :
                                        nh = atom.get_vector()
                                except:
                                    # Some atoms are missing
                                    # dihedral cannot be calculated for this residue
                                    ppl.append((None, None, None, None, None, None, None, None, None))
                                    res.xtra["DHAM"] = None
                                    res.xtra["DHBM"] = None
                                    res.xtra["DHCM"] = None
                                    res.xtra["DHDM"] = None
                                    res.xtra["DHEM"] = None
                                    res.xtra["DHFM"] = None
                                    res.xtra["DHAS"] = None
                                    res.xtra["DHBS"] = None
                                    res.xtra["DHCS"] = None
                                    continue
                            try:    
                                dhem = calc_dihedral(c4dp, c3dp, o3dp, p)
                            except:
                                dhem = None
                            try:
                                dhfm = calc_dihedral(c3dp, o3dp, p, o5d)
                            except:
                                dhfm = None
                            try:
                                dham = calc_dihedral(o3dp, p, o5d, c5d)
                            except:
                                dham = None
                            try:
                                dhbm = calc_dihedral(p, o5d, c5d, c4d)
                            except:
                                dhbm = None
                            try:
                                dhcm = calc_dihedral(o5d, c5d, c4d, o4d)
                            except:
                                dhcm = None
                            try:
                                dhdm = calc_dihedral(o4d, c4d, c3d, o3d)
                            except:
                                dhdm = None
                            try:
                                dhas = calc_dihedral(c1d, c2d, o2d, oh)
                            except:
                                dhas = None
                            try:
                                dhbs = calc_dihedral(o4d, c1d, n9, c8)
                            except:
                                dhbs = None
                            try:
                                dhcs = calc_dihedral(n1, c6, n6, nh)
                            except:
                                dhcs = None
                            ppl.append((dham, dhbm, dhcm, dhdm, dhem, dhfm, dhas, dhbs, dhcs))
                            # Add dihedral to xtra dict of residue
                            res.xtra["DHAM"] = dham
                            res.xtra["DHBM"] = dhbm
                            res.xtra["DHCM"] = dhcm
                            res.xtra["DHDM"] = dhdm
                            res.xtra["DHEM"] = dhem
                            res.xtra["DHFM"] = dhfm
                            res.xtra["DHAS"] = dhas
                            res.xtra["DHBS"] = dhbs
                            res.xtra["DHCS"] = dhcs
                            # translate dihedral to ConfCode
                            ccem = conf_code_al(dhem)
                            ccfm = conf_code_al(dhfm)
                            ccam = conf_code_al(dham)
                            ccbm = conf_code_al(dhbm)
                            cccm = conf_code_al(dhcm)
                            ccdm = conf_code_al(dhdm)
                            ccas = conf_code_al(dhas)
                            ccbs = conf_code_al(dhbs)
                            cccs = conf_code_al(dhcs)
                            ccem_st = "%s" % (ccem)
                            ccfm_st = "%s" % (ccfm)
                            ccam_st = "%s" % (ccam)
                            ccbm_st = "%s" % (ccbm)
                            cccm_st = "%s" % (cccm)
                            ccdm_st = "%s" % (ccdm)
                            ccas_st = "%s" % (ccas)
                            ccbs_st = "%s" % (ccbs)
                            cccs_st = "%s" % (cccs)
                            # SSC for RNA
                            lem = '6a'
                            lfm = '3a'
                            lam = '3a'
                            lbm = '1a'
                            lcm = '3a'
                            ldm = '6a'
                            mem = '6a'
                            mfm = '3a'
                            mam = '5c'
                            mbm = '1a'
                            mcm = '2c'
                            mdm = '6a'
                            #nem = '6a'
                            #nfm = '3a'
                            #nam = '5c'
                            #nbm = '1a'
                            #ncm = '3a'
                            #ndm = '6a'
                            #pem = '6a'
                            #pfm = '3a'
                            #pam = '3a'
                            #pbm = '1a'
                            #pcm = '2c'
                            #pdm = '6a'
                            #qem = '6a'
                            #qfm = '5c'
                            #qam = '3a'
                            #qbm = '1a'
                            #qcm = '3a'
                            #qdm = '6a'
                            #rem = '6a'
                            #rfm = '5c'
                            #am = '5c'
                            #bm = '1a'
                            #cm = '3a'
                            #dm = '6a'
                            #vem = '6a'
                            #vfm = '5c'
                            #vam = '3a'
                            #vbm = '1a'
                            #vcm = '2c'
                            #vdm = '6a'
                            #wem = '6a'
                            #wfm = '5c'
                            #wam = '5c'
                            #wbm = '1a'
                            #wcm = '2c'
                            #wdm = '6a'
                            try:
                                j_lem = _test_homology_al(ccem_st, lem)
                                j_mem = _test_homology_al(ccem_st, mem)
                                #j_nem = _test_homology_al(ccem_st, nem)
                                #j_pem = _test_homology_al(ccem_st, pem)
                                #j_qem = _test_homology_al(ccem_st, qem)
                                #j_rem = _test_homology_al(ccem_st, rem)
                                #j_vem = _test_homology_al(ccem_st, vem)
                                #j_wem = _test_homology_al(ccem_st, wem)
                                j_lfm = _test_homology_al(ccfm_st, lfm)
                                j_mfm = _test_homology_al(ccfm_st, mfm)
                                #j_nfm = _test_homology_al(ccfm_st, nfm)
                                #j_pfm = _test_homology_al(ccfm_st, pfm)
                                #j_qfm = _test_homology_al(ccfm_st, qfm)
                                #j_rfm = _test_homology_al(ccfm_st, rfm)
                                #j_vfm = _test_homology_al(ccfm_st, vfm)
                                #j_wfm = _test_homology_al(ccfm_st, wfm)
                                j_lam = _test_homology_al(ccam_st, lam)
                                j_mam = _test_homology_al(ccam_st, mam)
                                #j_nam = _test_homology_al(ccam_st, nam)
                                #j_pam = _test_homology_al(ccam_st, pam)
                                #j_qam = _test_homology_al(ccam_st, qam)
                                #j_ram = _test_homology_al(ccam_st, ram)
                                #j_vam = _test_homology_al(ccam_st, vam)
                                #j_wam = _test_homology_al(ccam_st, wam)
                                j_lbm = _test_homology_al(ccbm_st, lbm)
                                j_mbm = _test_homology_al(ccbm_st, mbm)
                                #j_nbm = _test_homology_al(ccbm_st, nbm)
                                #j_pbm = _test_homology_al(ccbm_st, pbm)
                                #j_qbm = _test_homology_al(ccbm_st, qbm)
                                #j_rbm = _test_homology_al(ccbm_st, rbm)
                                #j_vbm = _test_homology_al(ccbm_st, vbm)
                                #j_wbm = _test_homology_al(ccbm_st, wbm)
                                j_lcm = _test_homology_al(cccm_st, lcm)
                                j_mcm = _test_homology_al(cccm_st, mcm)
                                #j_ncm = _test_homology_al(cccm_st, ncm)
                                #j_pcm = _test_homology_al(cccm_st, pcm)
                                #j_qcm = _test_homology_al(cccm_st, qcm)
                                #j_rcm = _test_homology_al(cccm_st, rcm)
                                #j_vcm = _test_homology_al(cccm_st, vcm)
                                #j_wcm = _test_homology_al(cccm_st, wcm)
                                j_ldm = _test_homology_al(ccdm_st, ldm)
                                j_mdm = _test_homology_al(ccdm_st, mdm)
                                #j_ndm = _test_homology_al(ccdm_st, ndm)
                                #j_pdm = _test_homology_al(ccdm_st, pdm)
                                #j_qdm = _test_homology_al(ccdm_st, qdm)
                                #j_rdm = _test_homology_al(ccdm_st, rdm)
                                #j_vdm = _test_homology_al(ccdm_st, vdm)
                                #j_wdm = _test_homology_al(ccdm_st, wdm)
                                lc_l_mchain = j_lem*j_lfm*j_lam*j_lbm*j_lcm*j_ldm
                                lc_m_mchain = j_mem*j_mfm*j_mam*j_mbm*j_mcm*j_mdm
                                #lc_n_mchain = j_nem*j_nfm*j_nam*j_nbm*j_ncm*j_ndm
                                #lc_p_mchain = j_pem*j_pfm*j_pam*j_pbm*j_pcm*j_pdm
                                #lc_q_mchain = j_qem*j_qfm*j_qam*j_qbm*j_qcm*j_qdm
                                #lc_r_mchain = j_rem*j_rfm*j_ram*j_rbm*j_rcm*j_rdm
                                #lc_v_mchain = j_vem*j_vfm*j_vam*j_vbm*j_vcm*j_vdm
                                #lc_w_mchain = j_wem*j_wfm*j_wam*j_wbm*j_wcm*j_wdm
                                ssc_st = ""
                                if lc_l_mchain == 1 :
                                    ssc_st = "P"
                                elif lc_m_mchain == 1 :
                                    ssc_st = "S"
                                #elif lc_n_mchain == 1 :
                                    #ssc_st = "N"
                                #elif lc_p_mchain == 1 :
                                    #ssc_st = "P"
                                #elif lc_q_mchain == 1 :
                                    #ssc_st = "Q"
                                #elif lc_r_mchain == 1 :
                                    #ssc_st = "R"
                                #elif lc_v_mchain == 1 :
                                    #ssc_st = "V"
                                #elif lc_w_mchain == 1 :
                                    #ssc_st = "W"
                                else :
                                    ssc_st = "T"
                            except:
                                ssc_st = "D"
                            res_name = "%s%i" % (residue_name, residue_num)
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            fc.write('\t')
                            fc.write(ssc_st)                        
                            fc.write('\t')
                            fc.write(ccem_st)
                            fc.write('\t')
                            fc.write(ccfm_st)
                            fc.write('\t')
                            fc.write(ccam_st)
                            fc.write('\t')
                            fc.write(ccbm_st)
                            fc.write('\t')
                            fc.write(cccm_st)
                            fc.write('\t')
                            fc.write(ccdm_st)
                            fc.write('\t')
                            fc.write(ccas_st)
                            fc.write('\t')
                            fc.write(ccbs_st)
                            fc.write('\t')
                            fc.write(cccs_st)
                            fc.write('\n')
                            fc.close()
                            try:
                                c4dp = c4d
                                c3dp = c3d
                                o3dp = o3d
                                p = []
                                o5d = []
                                c5d = [] 
                                c4d = []
                                o4d = []
                                c3d = []
                                o3d = []
                                c2d = []
                                o2d = []
                                c1d = []
                                oh = []
                                n9 = []
                                c8 = []
                                c6 = []
                                n6 = []
                                n1 = []
                                nh = []
                                c2 = []
                                n2 = [] 
                                n3 = []
                                c4 = []
                                n4 = []
                            except:
                                continue
                        # G
                        elif residue_name == "G" :
                            for atom_index, atom in enumerate(residue) :
                                atom_id = atom.id
                                res = atom
                                try:
                                    if atom_id == "P" :
                                        p = atom.get_vector()
                                    elif atom_id == "O5'" :
                                        o5d = atom.get_vector()
                                    elif atom_id == "C5'" :
                                        c5d = atom.get_vector()
                                    elif atom_id == "C4'" :
                                        c4d = atom.get_vector()
                                    elif atom_id == "O4'" :
                                        o4d = atom.get_vector()
                                    elif atom_id == "C3'" :
                                        c3d = atom.get_vector()
                                    elif atom_id == "O3'" :
                                        o3d = atom.get_vector()
                                    elif atom_id == "C2'" :
                                        c2d = atom.get_vector()
                                    elif atom_id == "O2'" :
                                        o2d = atom.get_vector()
                                    elif atom_id == "C1'" :
                                        c1d = atom.get_vector()
                                    elif atom_id == "OH" :
                                        oh = atom.get_vector()
                                    elif atom_id == "N9" :
                                        n9 = atom.get_vector()
                                    elif atom_id == "C8" :
                                        c8 = atom.get_vector()
                                    elif atom_id == "C2" :
                                        c2 = atom.get_vector()
                                    elif atom_id == "N2" :
                                        n2 = atom.get_vector()
                                    elif atom_id == "N3" :
                                        n3 = atom.get_vector()
                                    elif atom_id == "NH" :
                                        nh = atom.get_vector()
                                except:
                                    # Some atoms are missing
                                    # dihedral cannot be calculated for this residue
                                    ppl.append((None, None, None, None, None, None, None, None, None))
                                    res.xtra["DHAM"] = None
                                    res.xtra["DHBM"] = None
                                    res.xtra["DHCM"] = None
                                    res.xtra["DHDM"] = None
                                    res.xtra["DHEM"] = None
                                    res.xtra["DHFM"] = None
                                    res.xtra["DHAS"] = None
                                    res.xtra["DHBS"] = None
                                    res.xtra["DHCS"] = None
                                    continue
                            try:    
                                dhem = calc_dihedral(c4dp, c3dp, o3dp, p)
                            except:
                                dhem = None
                            try:
                                dhfm = calc_dihedral(c3dp, o3dp, p, o5d)
                            except:
                                dhfm = None
                            try:
                                dham = calc_dihedral(o3dp, p, o5d, c5d)
                            except:
                                dham = None
                            try:
                                dhbm = calc_dihedral(p, o5d, c5d, c4d)
                            except:
                                dhbm = None
                            try:
                                dhcm = calc_dihedral(o5d, c5d, c4d, o4d)
                            except:
                                dhcm = None
                            try:
                                dhdm = calc_dihedral(o4d, c4d, c3d, o3d)
                            except:
                                dhdm = None
                            try:
                                dhas = calc_dihedral(c1d, c2d, o2d, oh)
                            except:
                                dhas = None
                            try:
                                dhbs = calc_dihedral(o4d, c1d, n9, c8)
                            except:
                                dhbs = None
                            try:
                                dhcs = calc_dihedral(n3, c2, n2, nh)
                            except:
                                dhcs = None
                            ppl.append((dham, dhbm, dhcm, dhdm, dhem, dhfm, dhas, dhbs, dhcs))
                            # Add dihedral to xtra dict of residue
                            res.xtra["DHAM"] = dham
                            res.xtra["DHBM"] = dhbm
                            res.xtra["DHCM"] = dhcm
                            res.xtra["DHDM"] = dhdm
                            res.xtra["DHEM"] = dhem
                            res.xtra["DHFM"] = dhfm
                            res.xtra["DHAS"] = dhas
                            res.xtra["DHBS"] = dhbs
                            res.xtra["DHCS"] = dhcs
                            # translate dihedral to ConfCode
                            ccem = conf_code_al(dhem)
                            ccfm = conf_code_al(dhfm)
                            ccam = conf_code_al(dham)
                            ccbm = conf_code_al(dhbm)
                            cccm = conf_code_al(dhcm)
                            ccdm = conf_code_al(dhdm)
                            ccas = conf_code_al(dhas)
                            ccbs = conf_code_al(dhbs)
                            cccs = conf_code_al(dhcs)
                            ccem_st = "%s" % (ccem)
                            ccfm_st = "%s" % (ccfm)
                            ccam_st = "%s" % (ccam)
                            ccbm_st = "%s" % (ccbm)
                            cccm_st = "%s" % (cccm)
                            ccdm_st = "%s" % (ccdm)
                            ccas_st = "%s" % (ccas)
                            ccbs_st = "%s" % (ccbs)
                            cccs_st = "%s" % (cccs)
                            # SSC for RNA
                            lem = '6a'
                            lfm = '3a'
                            lam = '3a'
                            lbm = '1a'
                            lcm = '3a'
                            ldm = '6a'
                            mem = '6a'
                            mfm = '3a'
                            mam = '5c'
                            mbm = '1a'
                            mcm = '2c'
                            mdm = '6a'
                            #nem = '6a'
                            #nfm = '3a'
                            #nam = '5c'
                            #nbm = '1a'
                            #ncm = '3a'
                            #ndm = '6a'
                            #pem = '6a'
                            #pfm = '3a'
                            #pam = '3a'
                            #pbm = '1a'
                            #pcm = '2c'
                            #pdm = '6a'
                            #qem = '6a'
                            #qfm = '5c'
                            #qam = '3a'
                            #qbm = '1a'
                            #qcm = '3a'
                            #qdm = '6a'
                            #rem = '6a'
                            #rfm = '5c'
                            #am = '5c'
                            #bm = '1a'
                            #cm = '3a'
                            #dm = '6a'
                            #vem = '6a'
                            #vfm = '5c'
                            #vam = '3a'
                            #vbm = '1a'
                            #vcm = '2c'
                            #vdm = '6a'
                            #wem = '6a'
                            #wfm = '5c'
                            #wam = '5c'
                            #wbm = '1a'
                            #wcm = '2c'
                            #wdm = '6a'
                            try:
                                j_lem = _test_homology_al(ccem_st, lem)
                                j_mem = _test_homology_al(ccem_st, mem)
                                #j_nem = _test_homology_al(ccem_st, nem)
                                #j_pem = _test_homology_al(ccem_st, pem)
                                #j_qem = _test_homology_al(ccem_st, qem)
                                #j_rem = _test_homology_al(ccem_st, rem)
                                #j_vem = _test_homology_al(ccem_st, vem)
                                #j_wem = _test_homology_al(ccem_st, wem)
                                j_lfm = _test_homology_al(ccfm_st, lfm)
                                j_mfm = _test_homology_al(ccfm_st, mfm)
                                #j_nfm = _test_homology_al(ccfm_st, nfm)
                                #j_pfm = _test_homology_al(ccfm_st, pfm)
                                #j_qfm = _test_homology_al(ccfm_st, qfm)
                                #j_rfm = _test_homology_al(ccfm_st, rfm)
                                #j_vfm = _test_homology_al(ccfm_st, vfm)
                                #j_wfm = _test_homology_al(ccfm_st, wfm)
                                j_lam = _test_homology_al(ccam_st, lam)
                                j_mam = _test_homology_al(ccam_st, mam)
                                #j_nam = _test_homology_al(ccam_st, nam)
                                #j_pam = _test_homology_al(ccam_st, pam)
                                #j_qam = _test_homology_al(ccam_st, qam)
                                #j_ram = _test_homology_al(ccam_st, ram)
                                #j_vam = _test_homology_al(ccam_st, vam)
                                #j_wam = _test_homology_al(ccam_st, wam)
                                j_lbm = _test_homology_al(ccbm_st, lbm)
                                j_mbm = _test_homology_al(ccbm_st, mbm)
                                #j_nbm = _test_homology_al(ccbm_st, nbm)
                                #j_pbm = _test_homology_al(ccbm_st, pbm)
                                #j_qbm = _test_homology_al(ccbm_st, qbm)
                                #j_rbm = _test_homology_al(ccbm_st, rbm)
                                #j_vbm = _test_homology_al(ccbm_st, vbm)
                                #j_wbm = _test_homology_al(ccbm_st, wbm)
                                j_lcm = _test_homology_al(cccm_st, lcm)
                                j_mcm = _test_homology_al(cccm_st, mcm)
                                #j_ncm = _test_homology_al(cccm_st, ncm)
                                #j_pcm = _test_homology_al(cccm_st, pcm)
                                #j_qcm = _test_homology_al(cccm_st, qcm)
                                #j_rcm = _test_homology_al(cccm_st, rcm)
                                #j_vcm = _test_homology_al(cccm_st, vcm)
                                #j_wcm = _test_homology_al(cccm_st, wcm)
                                j_ldm = _test_homology_al(ccdm_st, ldm)
                                j_mdm = _test_homology_al(ccdm_st, mdm)
                                #j_ndm = _test_homology_al(ccdm_st, ndm)
                                #j_pdm = _test_homology_al(ccdm_st, pdm)
                                #j_qdm = _test_homology_al(ccdm_st, qdm)
                                #j_rdm = _test_homology_al(ccdm_st, rdm)
                                #j_vdm = _test_homology_al(ccdm_st, vdm)
                                #j_wdm = _test_homology_al(ccdm_st, wdm)
                                lc_l_mchain = j_lem*j_lfm*j_lam*j_lbm*j_lcm*j_ldm
                                lc_m_mchain = j_mem*j_mfm*j_mam*j_mbm*j_mcm*j_mdm
                                #lc_n_mchain = j_nem*j_nfm*j_nam*j_nbm*j_ncm*j_ndm
                                #lc_p_mchain = j_pem*j_pfm*j_pam*j_pbm*j_pcm*j_pdm
                                #lc_q_mchain = j_qem*j_qfm*j_qam*j_qbm*j_qcm*j_qdm
                                #lc_r_mchain = j_rem*j_rfm*j_ram*j_rbm*j_rcm*j_rdm
                                #lc_v_mchain = j_vem*j_vfm*j_vam*j_vbm*j_vcm*j_vdm
                                #lc_w_mchain = j_wem*j_wfm*j_wam*j_wbm*j_wcm*j_wdm
                                ssc_st = ""
                                if lc_l_mchain == 1 :
                                    ssc_st = "P"
                                elif lc_m_mchain == 1 :
                                    ssc_st = "S"
                                #elif lc_n_mchain == 1 :
                                    #ssc_st = "N"
                                #elif lc_p_mchain == 1 :
                                    #ssc_st = "P"
                                #elif lc_q_mchain == 1 :
                                    #ssc_st = "Q"
                                #elif lc_r_mchain == 1 :
                                    #ssc_st = "R"
                                #elif lc_v_mchain == 1 :
                                    #ssc_st = "V"
                                #elif lc_w_mchain == 1 :
                                    #ssc_st = "W"
                                else :
                                    ssc_st = "T"
                            except:
                                ssc_st = "D"
                            res_name = "%s%i" % (residue_name, residue_num)
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            fc.write('\t')
                            fc.write(ssc_st)                        
                            fc.write('\t')                            
                            fc.write(ccem_st)
                            fc.write('\t')
                            fc.write(ccfm_st)
                            fc.write('\t')
                            fc.write(ccam_st)
                            fc.write('\t')
                            fc.write(ccbm_st)
                            fc.write('\t')
                            fc.write(cccm_st)
                            fc.write('\t')
                            fc.write(ccdm_st)
                            fc.write('\t')
                            fc.write(ccas_st)
                            fc.write('\t')
                            fc.write(ccbs_st)
                            fc.write('\t')
                            fc.write(cccs_st)
                            fc.write('\n')
                            fc.close()
                            try:
                                c4dp = c4d
                                c3dp = c3d
                                o3dp = o3d
                                p = []
                                o5d = []
                                c5d = [] 
                                c4d = []
                                o4d = []
                                c3d = []
                                o3d = []
                                c2d = []
                                o2d = []
                                c1d = []
                                oh = []
                                n9 = []
                                c8 = []
                                c6 = []
                                n6 = []
                                n1 = []
                                nh = []
                                c2 = []
                                n2 = [] 
                                n3 = []
                                c4 = []
                                n4 = [] 
                            except:
                                continue

                        # C
                        elif residue_name == "C" :
                            for atom_index, atom in enumerate(residue) :
                                atom_id = atom.id
                                res = atom
                                try:
                                    if atom_id == "P" :
                                        p = atom.get_vector()
                                    elif atom_id == "O5'" :
                                        o5d = atom.get_vector()
                                    elif atom_id == "C5'" :
                                        c5d = atom.get_vector()
                                    elif atom_id == "C4'" :
                                        c4d = atom.get_vector()
                                    elif atom_id == "O4'" :
                                        o4d = atom.get_vector()
                                    elif atom_id == "C3'" :
                                        c3d = atom.get_vector()
                                    elif atom_id == "O3'" :
                                        o3d = atom.get_vector()
                                    elif atom_id == "C2'" :
                                        c2d = atom.get_vector()
                                    elif atom_id == "O2'" :
                                        o2d = atom.get_vector()
                                    elif atom_id == "C1'" :
                                        c1d = atom.get_vector()
                                    elif atom_id == "OH" :
                                        oh = atom.get_vector()
                                    elif atom_id == "N1" :
                                        n1 = atom.get_vector()
                                    elif atom_id == "C2" :
                                        c2 = atom.get_vector()
                                    elif atom_id == "N3" :
                                        n3 = atom.get_vector()
                                    elif atom_id == "C4" :
                                        c4 = atom.get_vector()
                                    elif atom_id == "N4" :
                                        n4 = atom.get_vector()
                                    elif atom_id == "NH" :
                                        nh = atom.get_vector()
                                except:
                                    # Some atoms are missing
                                    # dihedral cannot be calculated for this residue
                                    ppl.append((None, None, None, None, None, None, None, None, None))
                                    res.xtra["DHAM"] = None
                                    res.xtra["DHBM"] = None
                                    res.xtra["DHCM"] = None
                                    res.xtra["DHDM"] = None
                                    res.xtra["DHEM"] = None
                                    res.xtra["DHFM"] = None
                                    res.xtra["DHAS"] = None
                                    res.xtra["DHBS"] = None
                                    res.xtra["DHCS"] = None
                                    continue
                            try:    
                                dhem = calc_dihedral(c4dp, c3dp, o3dp, p)
                            except:
                                dhem = None
                            try:
                                dhfm = calc_dihedral(c3dp, o3dp, p, o5d)
                            except:
                                dhfm = None
                            try:
                                dham = calc_dihedral(o3dp, p, o5d, c5d)
                            except:
                                dham = None
                            try:
                                dhbm = calc_dihedral(p, o5d, c5d, c4d)
                            except:
                                dhbm = None
                            try:
                                dhcm = calc_dihedral(o5d, c5d, c4d, o4d)
                            except:
                                dhcm = None
                            try:
                                dhdm = calc_dihedral(o4d, c4d, c3d, o3d)
                            except:
                                dhdm = None
                            try:
                                dhas = calc_dihedral(c1d, c2d, o2d, oh)
                            except:
                                dhas = None
                            try:
                                dhbs = calc_dihedral(o4d, c1d, n1, c2)
                            except:
                                dhbs = None
                            try:
                                dhcs = calc_dihedral(n3, c4, n4, nh)
                            except:
                                dhcs = None
                            ppl.append((dham, dhbm, dhcm, dhdm, dhem, dhfm, dhas, dhbs, dhcs))
                            # Add dihedral to xtra dict of residue
                            res.xtra["DHAM"] = dham
                            res.xtra["DHBM"] = dhbm
                            res.xtra["DHCM"] = dhcm
                            res.xtra["DHDM"] = dhdm
                            res.xtra["DHEM"] = dhem
                            res.xtra["DHFM"] = dhfm
                            res.xtra["DHAS"] = dhas
                            res.xtra["DHBS"] = dhbs
                            res.xtra["DHCS"] = dhcs
                            # translate dihedral to ConfCode
                            ccem = conf_code_al(dhem)
                            ccfm = conf_code_al(dhfm)
                            ccam = conf_code_al(dham)
                            ccbm = conf_code_al(dhbm)
                            cccm = conf_code_al(dhcm)
                            ccdm = conf_code_al(dhdm)
                            ccas = conf_code_al(dhas)
                            ccbs = conf_code_al(dhbs)
                            cccs = conf_code_al(dhcs)
                            ccem_st = "%s" % (ccem)
                            ccfm_st = "%s" % (ccfm)
                            ccam_st = "%s" % (ccam)
                            ccbm_st = "%s" % (ccbm)
                            cccm_st = "%s" % (cccm)
                            ccdm_st = "%s" % (ccdm)
                            ccas_st = "%s" % (ccas)
                            ccbs_st = "%s" % (ccbs)
                            cccs_st = "%s" % (cccs)
                            # SSC for RNA
                            lem = '6a'
                            lfm = '3a'
                            lam = '3a'
                            lbm = '1a'
                            lcm = '3a'
                            ldm = '6a'
                            mem = '6a'
                            mfm = '3a'
                            mam = '5c'
                            mbm = '1a'
                            mcm = '2c'
                            mdm = '6a'
                            #nem = '6a'
                            #nfm = '3a'
                            #nam = '5c'
                            #nbm = '1a'
                            #ncm = '3a'
                            #ndm = '6a'
                            #pem = '6a'
                            #pfm = '3a'
                            #pam = '3a'
                            #pbm = '1a'
                            #pcm = '2c'
                            #pdm = '6a'
                            #qem = '6a'
                            #qfm = '5c'
                            #qam = '3a'
                            #qbm = '1a'
                            #qcm = '3a'
                            #qdm = '6a'
                            #rem = '6a'
                            #rfm = '5c'
                            #am = '5c'
                            #bm = '1a'
                            #cm = '3a'
                            #dm = '6a'
                            #vem = '6a'
                            #vfm = '5c'
                            #vam = '3a'
                            #vbm = '1a'
                            #vcm = '2c'
                            #vdm = '6a'
                            #wem = '6a'
                            #wfm = '5c'
                            #wam = '5c'
                            #wbm = '1a'
                            #wcm = '2c'
                            #wdm = '6a'
                            try:
                                j_lem = _test_homology_al(ccem_st, lem)
                                j_mem = _test_homology_al(ccem_st, mem)
                                #j_nem = _test_homology_al(ccem_st, nem)
                                #j_pem = _test_homology_al(ccem_st, pem)
                                #j_qem = _test_homology_al(ccem_st, qem)
                                #j_rem = _test_homology_al(ccem_st, rem)
                                #j_vem = _test_homology_al(ccem_st, vem)
                                #j_wem = _test_homology_al(ccem_st, wem)
                                j_lfm = _test_homology_al(ccfm_st, lfm)
                                j_mfm = _test_homology_al(ccfm_st, mfm)
                                #j_nfm = _test_homology_al(ccfm_st, nfm)
                                #j_pfm = _test_homology_al(ccfm_st, pfm)
                                #j_qfm = _test_homology_al(ccfm_st, qfm)
                                #j_rfm = _test_homology_al(ccfm_st, rfm)
                                #j_vfm = _test_homology_al(ccfm_st, vfm)
                                #j_wfm = _test_homology_al(ccfm_st, wfm)
                                j_lam = _test_homology_al(ccam_st, lam)
                                j_mam = _test_homology_al(ccam_st, mam)
                                #j_nam = _test_homology_al(ccam_st, nam)
                                #j_pam = _test_homology_al(ccam_st, pam)
                                #j_qam = _test_homology_al(ccam_st, qam)
                                #j_ram = _test_homology_al(ccam_st, ram)
                                #j_vam = _test_homology_al(ccam_st, vam)
                                #j_wam = _test_homology_al(ccam_st, wam)
                                j_lbm = _test_homology_al(ccbm_st, lbm)
                                j_mbm = _test_homology_al(ccbm_st, mbm)
                                #j_nbm = _test_homology_al(ccbm_st, nbm)
                                #j_pbm = _test_homology_al(ccbm_st, pbm)
                                #j_qbm = _test_homology_al(ccbm_st, qbm)
                                #j_rbm = _test_homology_al(ccbm_st, rbm)
                                #j_vbm = _test_homology_al(ccbm_st, vbm)
                                #j_wbm = _test_homology_al(ccbm_st, wbm)
                                j_lcm = _test_homology_al(cccm_st, lcm)
                                j_mcm = _test_homology_al(cccm_st, mcm)
                                #j_ncm = _test_homology_al(cccm_st, ncm)
                                #j_pcm = _test_homology_al(cccm_st, pcm)
                                #j_qcm = _test_homology_al(cccm_st, qcm)
                                #j_rcm = _test_homology_al(cccm_st, rcm)
                                #j_vcm = _test_homology_al(cccm_st, vcm)
                                #j_wcm = _test_homology_al(cccm_st, wcm)
                                j_ldm = _test_homology_al(ccdm_st, ldm)
                                j_mdm = _test_homology_al(ccdm_st, mdm)
                                #j_ndm = _test_homology_al(ccdm_st, ndm)
                                #j_pdm = _test_homology_al(ccdm_st, pdm)
                                #j_qdm = _test_homology_al(ccdm_st, qdm)
                                #j_rdm = _test_homology_al(ccdm_st, rdm)
                                #j_vdm = _test_homology_al(ccdm_st, vdm)
                                #j_wdm = _test_homology_al(ccdm_st, wdm)
                                lc_l_mchain = j_lem*j_lfm*j_lam*j_lbm*j_lcm*j_ldm
                                lc_m_mchain = j_mem*j_mfm*j_mam*j_mbm*j_mcm*j_mdm
                                #lc_n_mchain = j_nem*j_nfm*j_nam*j_nbm*j_ncm*j_ndm
                                #lc_p_mchain = j_pem*j_pfm*j_pam*j_pbm*j_pcm*j_pdm
                                #lc_q_mchain = j_qem*j_qfm*j_qam*j_qbm*j_qcm*j_qdm
                                #lc_r_mchain = j_rem*j_rfm*j_ram*j_rbm*j_rcm*j_rdm
                                #lc_v_mchain = j_vem*j_vfm*j_vam*j_vbm*j_vcm*j_vdm
                                #lc_w_mchain = j_wem*j_wfm*j_wam*j_wbm*j_wcm*j_wdm
                                ssc_st = ""
                                if lc_l_mchain == 1 :
                                    ssc_st = "P"
                                elif lc_m_mchain == 1 :
                                    ssc_st = "S"
                                #elif lc_n_mchain == 1 :
                                    #ssc_st = "N"
                                #elif lc_p_mchain == 1 :
                                    #ssc_st = "P"
                                #elif lc_q_mchain == 1 :
                                    #ssc_st = "Q"
                                #elif lc_r_mchain == 1 :
                                    #ssc_st = "R"
                                #elif lc_v_mchain == 1 :
                                    #ssc_st = "V"
                                #elif lc_w_mchain == 1 :
                                    #ssc_st = "W"
                                else :
                                    ssc_st = "T"
                            except:
                                ssc_st = "D"
                            res_name = "%s%i" % (residue_name, residue_num)
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            fc.write('\t')
                            fc.write(ssc_st)                        
                            fc.write('\t')                            
                            fc.write(ccem_st)
                            fc.write('\t')
                            fc.write(ccfm_st)
                            fc.write('\t')
                            fc.write(ccam_st)
                            fc.write('\t')
                            fc.write(ccbm_st)
                            fc.write('\t')
                            fc.write(cccm_st)
                            fc.write('\t')
                            fc.write(ccdm_st)
                            fc.write('\t')
                            fc.write(ccas_st)
                            fc.write('\t')
                            fc.write(ccbs_st)
                            fc.write('\t')
                            fc.write(cccs_st)
                            fc.write('\n')
                            fc.close()
                            try:
                                c4dp = c4d
                                c3dp = c3d
                                o3dp = o3d
                                p = []
                                o5d = []
                                c5d = [] 
                                c4d = []
                                o4d = []
                                c3d = []
                                o3d = []
                                c2d = []
                                o2d = []
                                c1d = []
                                oh = []
                                n9 = []
                                c8 = []
                                c6 = []
                                n6 = []
                                n1 = []
                                nh = []
                                c2 = []
                                n2 = [] 
                                n3 = []
                                c4 = []
                                n4 = [] 
                            except:
                                continue

                        # U
                        elif residue_name == "U" :
                            for atom_index, atom in enumerate(residue) :
                                atom_id = atom.id
                                res = atom
                                try:
                                    if atom_id == "P" :
                                        p = atom.get_vector()
                                    elif atom_id == "O5'" :
                                        o5d = atom.get_vector()
                                    elif atom_id == "C5'" :
                                        c5d = atom.get_vector()
                                    elif atom_id == "C4'" :
                                        c4d = atom.get_vector()
                                    elif atom_id == "O4'" :
                                        o4d = atom.get_vector()
                                    elif atom_id == "C3'" :
                                        c3d = atom.get_vector()
                                    elif atom_id == "O3'" :
                                        o3d = atom.get_vector()
                                    elif atom_id == "C2'" :
                                        c2d = atom.get_vector()
                                    elif atom_id == "O2'" :
                                        o2d = atom.get_vector()
                                    elif atom_id == "C1'" :
                                        c1d = atom.get_vector()
                                    elif atom_id == "OH" :
                                        oh = atom.get_vector()
                                    elif atom_id == "N1" :
                                        n1 = atom.get_vector()
                                    elif atom_id == "C2" :
                                        c2 = atom.get_vector()
                                except:
                                    # Some atoms are missing
                                    # dihedral cannot be calculated for this residue
                                    ppl.append((None, None, None, None, None, None, None, None, None))
                                    res.xtra["DHAM"] = None
                                    res.xtra["DHBM"] = None
                                    res.xtra["DHCM"] = None
                                    res.xtra["DHDM"] = None
                                    res.xtra["DHEM"] = None
                                    res.xtra["DHFM"] = None
                                    res.xtra["DHAS"] = None
                                    res.xtra["DHBS"] = None
                                    res.xtra["DHCS"] = None
                                    continue
                            try:    
                                dhem = calc_dihedral(c4dp, c3dp, o3dp, p)
                            except:
                                dhem = None
                            try:
                                dhfm = calc_dihedral(c3dp, o3dp, p, o5d)
                            except:
                                dhfm = None
                            try:
                                dham = calc_dihedral(o3dp, p, o5d, c5d)
                            except:
                                dham = None
                            try:
                                dhbm = calc_dihedral(p, o5d, c5d, c4d)
                            except:
                                dhbm = None
                            try:
                                dhcm = calc_dihedral(o5d, c5d, c4d, o4d)
                            except:
                                dhcm = None
                            try:
                                dhdm = calc_dihedral(o4d, c4d, c3d, o3d)
                            except:
                                dhdm = None
                            try:
                                dhas = calc_dihedral(c1d, c2d, o2d, oh)
                            except:
                                dhas = None
                            try:
                                dhbs = calc_dihedral(o4d, c1d, n1, c2)
                            except:
                                dhbs = None
                            dhcs = None
                            ppl.append((dham, dhbm, dhcm, dhdm, dhem, dhfm, dhas, dhbs, dhcs))                    
                            # Add dihedral to xtra dict of residue
                            res.xtra["DHAM"] = dham
                            res.xtra["DHBM"] = dhbm
                            res.xtra["DHCM"] = dhcm
                            res.xtra["DHDM"] = dhdm
                            res.xtra["DHEM"] = dhem
                            res.xtra["DHFM"] = dhfm
                            res.xtra["DHAS"] = dhas
                            res.xtra["DHBS"] = dhbs
                            res.xtra["DHCS"] = dhcs
                            # translate dihedral to ConfCode
                            ccem = conf_code_al(dhem)
                            ccfm = conf_code_al(dhfm)
                            ccam = conf_code_al(dham)
                            ccbm = conf_code_al(dhbm)
                            cccm = conf_code_al(dhcm)
                            ccdm = conf_code_al(dhdm)
                            ccas = conf_code_al(dhas)
                            ccbs = conf_code_al(dhbs)
                            cccs = conf_code_al(dhcs)
                            ccem_st = "%s" % (ccem)
                            ccfm_st = "%s" % (ccfm)
                            ccam_st = "%s" % (ccam)
                            ccbm_st = "%s" % (ccbm)
                            cccm_st = "%s" % (cccm)
                            ccdm_st = "%s" % (ccdm)
                            ccas_st = "%s" % (ccas)
                            ccbs_st = "%s" % (ccbs)
                            cccs_st = "%s" % (cccs)
                            # SSC for RNA
                            lem = '6a'
                            lfm = '3a'
                            lam = '3a'
                            lbm = '1a'
                            lcm = '3a'
                            ldm = '6a'
                            mem = '6a'
                            mfm = '3a'
                            mam = '5c'
                            mbm = '1a'
                            mcm = '2c'
                            mdm = '6a'
                            #nem = '6a'
                            #nfm = '3a'
                            #nam = '5c'
                            #nbm = '1a'
                            #ncm = '3a'
                            #ndm = '6a'
                            #pem = '6a'
                            #pfm = '3a'
                            #pam = '3a'
                            #pbm = '1a'
                            #pcm = '2c'
                            #pdm = '6a'
                            #qem = '6a'
                            #qfm = '5c'
                            #qam = '3a'
                            #qbm = '1a'
                            #qcm = '3a'
                            #qdm = '6a'
                            #rem = '6a'
                            #rfm = '5c'
                            #am = '5c'
                            #bm = '1a'
                            #cm = '3a'
                            #dm = '6a'
                            #vem = '6a'
                            #vfm = '5c'
                            #vam = '3a'
                            #vbm = '1a'
                            #vcm = '2c'
                            #vdm = '6a'
                            #wem = '6a'
                            #wfm = '5c'
                            #wam = '5c'
                            #wbm = '1a'
                            #wcm = '2c'
                            #wdm = '6a'
                            try:
                                j_lem = _test_homology_al(ccem_st, lem)
                                j_mem = _test_homology_al(ccem_st, mem)
                                #j_nem = _test_homology_al(ccem_st, nem)
                                #j_pem = _test_homology_al(ccem_st, pem)
                                #j_qem = _test_homology_al(ccem_st, qem)
                                #j_rem = _test_homology_al(ccem_st, rem)
                                #j_vem = _test_homology_al(ccem_st, vem)
                                #j_wem = _test_homology_al(ccem_st, wem)
                                j_lfm = _test_homology_al(ccfm_st, lfm)
                                j_mfm = _test_homology_al(ccfm_st, mfm)
                                #j_nfm = _test_homology_al(ccfm_st, nfm)
                                #j_pfm = _test_homology_al(ccfm_st, pfm)
                                #j_qfm = _test_homology_al(ccfm_st, qfm)
                                #j_rfm = _test_homology_al(ccfm_st, rfm)
                                #j_vfm = _test_homology_al(ccfm_st, vfm)
                                #j_wfm = _test_homology_al(ccfm_st, wfm)
                                j_lam = _test_homology_al(ccam_st, lam)
                                j_mam = _test_homology_al(ccam_st, mam)
                                #j_nam = _test_homology_al(ccam_st, nam)
                                #j_pam = _test_homology_al(ccam_st, pam)
                                #j_qam = _test_homology_al(ccam_st, qam)
                                #j_ram = _test_homology_al(ccam_st, ram)
                                #j_vam = _test_homology_al(ccam_st, vam)
                                #j_wam = _test_homology_al(ccam_st, wam)
                                j_lbm = _test_homology_al(ccbm_st, lbm)
                                j_mbm = _test_homology_al(ccbm_st, mbm)
                                #j_nbm = _test_homology_al(ccbm_st, nbm)
                                #j_pbm = _test_homology_al(ccbm_st, pbm)
                                #j_qbm = _test_homology_al(ccbm_st, qbm)
                                #j_rbm = _test_homology_al(ccbm_st, rbm)
                                #j_vbm = _test_homology_al(ccbm_st, vbm)
                                #j_wbm = _test_homology_al(ccbm_st, wbm)
                                j_lcm = _test_homology_al(cccm_st, lcm)
                                j_mcm = _test_homology_al(cccm_st, mcm)
                                #j_ncm = _test_homology_al(cccm_st, ncm)
                                #j_pcm = _test_homology_al(cccm_st, pcm)
                                #j_qcm = _test_homology_al(cccm_st, qcm)
                                #j_rcm = _test_homology_al(cccm_st, rcm)
                                #j_vcm = _test_homology_al(cccm_st, vcm)
                                #j_wcm = _test_homology_al(cccm_st, wcm)
                                j_ldm = _test_homology_al(ccdm_st, ldm)
                                j_mdm = _test_homology_al(ccdm_st, mdm)
                                #j_ndm = _test_homology_al(ccdm_st, ndm)
                                #j_pdm = _test_homology_al(ccdm_st, pdm)
                                #j_qdm = _test_homology_al(ccdm_st, qdm)
                                #j_rdm = _test_homology_al(ccdm_st, rdm)
                                #j_vdm = _test_homology_al(ccdm_st, vdm)
                                #j_wdm = _test_homology_al(ccdm_st, wdm)
                                lc_l_mchain = j_lem*j_lfm*j_lam*j_lbm*j_lcm*j_ldm
                                lc_m_mchain = j_mem*j_mfm*j_mam*j_mbm*j_mcm*j_mdm
                                #lc_n_mchain = j_nem*j_nfm*j_nam*j_nbm*j_ncm*j_ndm
                                #lc_p_mchain = j_pem*j_pfm*j_pam*j_pbm*j_pcm*j_pdm
                                #lc_q_mchain = j_qem*j_qfm*j_qam*j_qbm*j_qcm*j_qdm
                                #lc_r_mchain = j_rem*j_rfm*j_ram*j_rbm*j_rcm*j_rdm
                                #lc_v_mchain = j_vem*j_vfm*j_vam*j_vbm*j_vcm*j_vdm
                                #lc_w_mchain = j_wem*j_wfm*j_wam*j_wbm*j_wcm*j_wdm
                                ssc_st = ""
                                if lc_l_mchain == 1 :
                                    ssc_st = "P"
                                elif lc_m_mchain == 1 :
                                    ssc_st = "S"
                                #elif lc_n_mchain == 1 :
                                    #ssc_st = "N"
                                #elif lc_p_mchain == 1 :
                                    #ssc_st = "P"
                                #elif lc_q_mchain == 1 :
                                    #ssc_st = "Q"
                                #elif lc_r_mchain == 1 :
                                    #ssc_st = "R"
                                #elif lc_v_mchain == 1 :
                                    #ssc_st = "V"
                                #elif lc_w_mchain == 1 :
                                    #ssc_st = "W"
                                else :
                                    ssc_st = "T"
                            except:
                                ssc_st = "D"
                            res_name = "%s%i" % (residue_name, residue_num)
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            fc.write('\t')
                            fc.write(ssc_st)                        
                            fc.write('\t')                            
                            fc.write(ccem_st)
                            fc.write('\t')
                            fc.write(ccfm_st)
                            fc.write('\t')
                            fc.write(ccam_st)
                            fc.write('\t')
                            fc.write(ccbm_st)
                            fc.write('\t')
                            fc.write(cccm_st)
                            fc.write('\t')
                            fc.write(ccdm_st)
                            fc.write('\t')
                            fc.write(ccas_st)
                            fc.write('\t')
                            fc.write(ccbs_st)
                            fc.write('\t')
                            fc.write(cccs_st)
                            fc.write('\n')
                            fc.close()
                            try:
                                c4dp = c4d
                                c3dp = c3d
                                o3dp = o3d
                                p = []
                                o5d = []
                                c5d = [] 
                                c4d = []
                                o4d = []
                                c3d = []
                                o3d = []
                                c2d = []
                                o2d = []
                                c1d = []
                                oh = []
                                n9 = []
                                c8 = []
                                c6 = []
                                n6 = []
                                n1 = []
                                nh = []
                                c2 = []
                                n2 = [] 
                                n3 = []
                                c4 = []
                                n4 = []
                            except:
                                continue
                                
                        else:
                            continue
                    else:
                        ppl=[]
                        fc = open(str(fname), 'a')
                        fc.write('')                        
                        mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                        mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                        mname3 = "length %i " % (len(residue))
                        if residue_index > 0:
                            if residue_num != residue_nump + 1:
                                fc.write("X")
                                fc.write('\n')
                        fc.close()
                        residue_nump = residue_num
                        # A
                        if residue_name == "A" :
                            for atom_index, atom in enumerate(residue) :
                                atom_id = atom.id
                                res = atom
                                try:
                                    if atom_id == "P" :
                                        p = atom.get_vector()
                                    elif atom_id == "O5'" :
                                        o5d = atom.get_vector()
                                    elif atom_id == "C5'" :
                                        c5d = atom.get_vector()
                                    elif atom_id == "C4'" :
                                        c4d = atom.get_vector()
                                    elif atom_id == "O4'" :
                                        o4d = atom.get_vector()
                                    elif atom_id == "C3'" :
                                        c3d = atom.get_vector()
                                    elif atom_id == "O3'" :
                                        o3d = atom.get_vector()
                                    elif atom_id == "C2'" :
                                        c2d = atom.get_vector()
                                    elif atom_id == "O2'" :
                                        o2d = atom.get_vector()
                                    elif atom_id == "C1'" :
                                        c1d = atom.get_vector()
                                    elif atom_id == "OH" :
                                        oh = atom.get_vector()
                                    elif atom_id == "N9" :
                                        n9 = atom.get_vector()
                                    elif atom_id == "C8" :
                                        c8 = atom.get_vector()
                                    elif atom_id == "C6" :
                                        c6 = atom.get_vector()
                                    elif atom_id == "N6" :
                                        n6 = atom.get_vector()
                                    elif atom_id == "N1" :
                                        n1 = atom.get_vector()
                                    elif atom_id == "NH" :
                                        nh = atom.get_vector()
                                except:
                                    # Some atoms are missing
                                    # dihedral cannot be calculated for this residue
                                    ppl.append((None, None, None, None, None, None, None, None, None))
                                    res.xtra["DHAM"] = None
                                    res.xtra["DHBM"] = None
                                    res.xtra["DHCM"] = None
                                    res.xtra["DHDM"] = None
                                    res.xtra["DHEM"] = None
                                    res.xtra["DHFM"] = None
                                    res.xtra["DHAS"] = None
                                    res.xtra["DHBS"] = None
                                    res.xtra["DHCS"] = None
                                    continue
                            try:    
                                dhem = calc_dihedral(c4dp, c3dp, o3dp, p)
                            except:
                                dhem = None
                            try:
                                dhfm = calc_dihedral(c3dp, o3dp, p, o5d)
                            except:
                                dhfm = None
                            try:
                                dham = calc_dihedral(o3dp, p, o5d, c5d)
                            except:
                                dham = None
                            try:
                                dhbm = calc_dihedral(p, o5d, c5d, c4d)
                            except:
                                dhbm = None
                            try:
                                dhcm = calc_dihedral(o5d, c5d, c4d, o4d)
                            except:
                                dhcm = None
                            try:
                                dhdm = calc_dihedral(o4d, c4d, c3d, o3d)
                            except:
                                dhdm = None
                            try:
                                dhas = calc_dihedral(c1d, c2d, o2d, oh)
                            except:
                                dhas = None
                            try:
                                dhbs = calc_dihedral(o4d, c1d, n9, c8)
                            except:
                                dhbs = None
                            try:
                                dhcs = calc_dihedral(n1, c6, n6, nh)
                            except:
                                dhcs = None
                            ppl.append((dham, dhbm, dhcm, dhdm, dhem, dhfm, dhas, dhbs, dhcs))
                            # Add dihedral to xtra dict of residue
                            res.xtra["DHAM"] = dham
                            res.xtra["DHBM"] = dhbm
                            res.xtra["DHCM"] = dhcm
                            res.xtra["DHDM"] = dhdm
                            res.xtra["DHEM"] = dhem
                            res.xtra["DHFM"] = dhfm
                            res.xtra["DHAS"] = dhas
                            res.xtra["DHBS"] = dhbs
                            res.xtra["DHCS"] = dhcs
                            # translate dihedral to ConfCode
                            ccem = conf_code_al(dhem)
                            ccfm = conf_code_al(dhfm)
                            ccam = conf_code_al(dham)
                            ccbm = conf_code_al(dhbm)
                            cccm = conf_code_al(dhcm)
                            ccdm = conf_code_al(dhdm)
                            ccas = conf_code_al(dhas)
                            ccbs = conf_code_al(dhbs)
                            cccs = conf_code_al(dhcs)
                            ccem_st = "%s" % (ccem)
                            ccfm_st = "%s" % (ccfm)
                            ccam_st = "%s" % (ccam)
                            ccbm_st = "%s" % (ccbm)
                            cccm_st = "%s" % (cccm)
                            ccdm_st = "%s" % (ccdm)
                            ccas_st = "%s" % (ccas)
                            ccbs_st = "%s" % (ccbs)
                            cccs_st = "%s" % (cccs)
                            # SSC for RNA
                            lem = '6a'
                            lfm = '3a'
                            lam = '3a'
                            lbm = '1a'
                            lcm = '3a'
                            ldm = '6a'
                            mem = '6a'
                            mfm = '3a'
                            mam = '5c'
                            mbm = '1a'
                            mcm = '2c'
                            mdm = '6a'
                            #nem = '6a'
                            #nfm = '3a'
                            #nam = '5c'
                            #nbm = '1a'
                            #ncm = '3a'
                            #ndm = '6a'
                            #pem = '6a'
                            #pfm = '3a'
                            #pam = '3a'
                            #pbm = '1a'
                            #pcm = '2c'
                            #pdm = '6a'
                            #qem = '6a'
                            #qfm = '5c'
                            #qam = '3a'
                            #qbm = '1a'
                            #qcm = '3a'
                            #qdm = '6a'
                            #rem = '6a'
                            #rfm = '5c'
                            #am = '5c'
                            #bm = '1a'
                            #cm = '3a'
                            #dm = '6a'
                            #vem = '6a'
                            #vfm = '5c'
                            #vam = '3a'
                            #vbm = '1a'
                            #vcm = '2c'
                            #vdm = '6a'
                            #wem = '6a'
                            #wfm = '5c'
                            #wam = '5c'
                            #wbm = '1a'
                            #wcm = '2c'
                            #wdm = '6a'
                            try:
                                j_lem = _test_homology_al(ccem_st, lem)
                                j_mem = _test_homology_al(ccem_st, mem)
                                #j_nem = _test_homology_al(ccem_st, nem)
                                #j_pem = _test_homology_al(ccem_st, pem)
                                #j_qem = _test_homology_al(ccem_st, qem)
                                #j_rem = _test_homology_al(ccem_st, rem)
                                #j_vem = _test_homology_al(ccem_st, vem)
                                #j_wem = _test_homology_al(ccem_st, wem)
                                j_lfm = _test_homology_al(ccfm_st, lfm)
                                j_mfm = _test_homology_al(ccfm_st, mfm)
                                #j_nfm = _test_homology_al(ccfm_st, nfm)
                                #j_pfm = _test_homology_al(ccfm_st, pfm)
                                #j_qfm = _test_homology_al(ccfm_st, qfm)
                                #j_rfm = _test_homology_al(ccfm_st, rfm)
                                #j_vfm = _test_homology_al(ccfm_st, vfm)
                                #j_wfm = _test_homology_al(ccfm_st, wfm)
                                j_lam = _test_homology_al(ccam_st, lam)
                                j_mam = _test_homology_al(ccam_st, mam)
                                #j_nam = _test_homology_al(ccam_st, nam)
                                #j_pam = _test_homology_al(ccam_st, pam)
                                #j_qam = _test_homology_al(ccam_st, qam)
                                #j_ram = _test_homology_al(ccam_st, ram)
                                #j_vam = _test_homology_al(ccam_st, vam)
                                #j_wam = _test_homology_al(ccam_st, wam)
                                j_lbm = _test_homology_al(ccbm_st, lbm)
                                j_mbm = _test_homology_al(ccbm_st, mbm)
                                #j_nbm = _test_homology_al(ccbm_st, nbm)
                                #j_pbm = _test_homology_al(ccbm_st, pbm)
                                #j_qbm = _test_homology_al(ccbm_st, qbm)
                                #j_rbm = _test_homology_al(ccbm_st, rbm)
                                #j_vbm = _test_homology_al(ccbm_st, vbm)
                                #j_wbm = _test_homology_al(ccbm_st, wbm)
                                j_lcm = _test_homology_al(cccm_st, lcm)
                                j_mcm = _test_homology_al(cccm_st, mcm)
                                #j_ncm = _test_homology_al(cccm_st, ncm)
                                #j_pcm = _test_homology_al(cccm_st, pcm)
                                #j_qcm = _test_homology_al(cccm_st, qcm)
                                #j_rcm = _test_homology_al(cccm_st, rcm)
                                #j_vcm = _test_homology_al(cccm_st, vcm)
                                #j_wcm = _test_homology_al(cccm_st, wcm)
                                j_ldm = _test_homology_al(ccdm_st, ldm)
                                j_mdm = _test_homology_al(ccdm_st, mdm)
                                #j_ndm = _test_homology_al(ccdm_st, ndm)
                                #j_pdm = _test_homology_al(ccdm_st, pdm)
                                #j_qdm = _test_homology_al(ccdm_st, qdm)
                                #j_rdm = _test_homology_al(ccdm_st, rdm)
                                #j_vdm = _test_homology_al(ccdm_st, vdm)
                                #j_wdm = _test_homology_al(ccdm_st, wdm)
                                lc_l_mchain = j_lem*j_lfm*j_lam*j_lbm*j_lcm*j_ldm
                                lc_m_mchain = j_mem*j_mfm*j_mam*j_mbm*j_mcm*j_mdm
                                #lc_n_mchain = j_nem*j_nfm*j_nam*j_nbm*j_ncm*j_ndm
                                #lc_p_mchain = j_pem*j_pfm*j_pam*j_pbm*j_pcm*j_pdm
                                #lc_q_mchain = j_qem*j_qfm*j_qam*j_qbm*j_qcm*j_qdm
                                #lc_r_mchain = j_rem*j_rfm*j_ram*j_rbm*j_rcm*j_rdm
                                #lc_v_mchain = j_vem*j_vfm*j_vam*j_vbm*j_vcm*j_vdm
                                #lc_w_mchain = j_wem*j_wfm*j_wam*j_wbm*j_wcm*j_wdm
                                ssc_st = ""
                                if lc_l_mchain == 1 :
                                    ssc_st = "P"
                                elif lc_m_mchain == 1 :
                                    ssc_st = "S"
                                #elif lc_n_mchain == 1 :
                                    #ssc_st = "N"
                                #elif lc_p_mchain == 1 :
                                    #ssc_st = "P"
                                #elif lc_q_mchain == 1 :
                                    #ssc_st = "Q"
                                #elif lc_r_mchain == 1 :
                                    #ssc_st = "R"
                                #elif lc_v_mchain == 1 :
                                    #ssc_st = "V"
                                #elif lc_w_mchain == 1 :
                                    #ssc_st = "W"
                                else :
                                    ssc_st = "T"
                            except:
                                ssc_st = "D"
                            res_name = "%s%i" % (residue_name, residue_num)
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            fc.write('\t')
                            fc.write(ssc_st)                        
                            fc.write('\t')                            
                            fc.write(ccem_st)
                            fc.write('\t')
                            fc.write(ccfm_st)
                            fc.write('\t')
                            fc.write(ccam_st)
                            fc.write('\t')
                            fc.write(ccbm_st)
                            fc.write('\t')
                            fc.write(cccm_st)
                            fc.write('\t')
                            fc.write(ccdm_st)
                            fc.write('\t')
                            fc.write(ccas_st)
                            fc.write('\t')
                            fc.write(ccbs_st)
                            fc.write('\t')
                            fc.write(cccs_st)
                            fc.write('\n')
                            fc.close()
                            try:
                                c4dp = c4d
                                c3dp = c3d
                                o3dp = o3d
                                p = []
                                o5d = []
                                c5d = [] 
                                c4d = []
                                o4d = []
                                c3d = []
                                o3d = []
                                c2d = []
                                o2d = []
                                c1d = []
                                oh = []
                                n9 = []
                                c8 = []
                                c6 = []
                                n6 = []
                                n1 = []
                                nh = []
                                c2 = []
                                n2 = [] 
                                n3 = []
                                c4 = []
                                n4 = []                                
                            except:
                                continue
                            
                        # G
                        elif residue_name == "G" :
                            for atom_index, atom in enumerate(residue) :
                                atom_id = atom.id
                                res = atom
                                try:
                                    if atom_id == "P" :
                                        p = atom.get_vector()
                                    elif atom_id == "O5'" :
                                        o5d = atom.get_vector()
                                    elif atom_id == "C5'" :
                                        c5d = atom.get_vector()
                                    elif atom_id == "C4'" :
                                        c4d = atom.get_vector()
                                    elif atom_id == "O4'" :
                                        o4d = atom.get_vector()
                                    elif atom_id == "C3'" :
                                        c3d = atom.get_vector()
                                    elif atom_id == "O3'" :
                                        o3d = atom.get_vector()
                                    elif atom_id == "C2'" :
                                        c2d = atom.get_vector()
                                    elif atom_id == "O2'" :
                                        o2d = atom.get_vector()
                                    elif atom_id == "C1'" :
                                        c1d = atom.get_vector()
                                    elif atom_id == "OH" :
                                        oh = atom.get_vector()
                                    elif atom_id == "N9" :
                                        n9 = atom.get_vector()
                                    elif atom_id == "C8" :
                                        c8 = atom.get_vector()
                                    elif atom_id == "C2" :
                                        c2 = atom.get_vector()
                                    elif atom_id == "N2" :
                                        n2 = atom.get_vector()
                                    elif atom_id == "N3" :
                                        n3 = atom.get_vector()
                                    elif atom_id == "NH" :
                                        nh = atom.get_vector()
                                except:
                                    # Some atoms are missing
                                    # dihedral cannot be calculated for this residue
                                    ppl.append((None, None, None, None, None, None, None, None, None))
                                    res.xtra["DHAM"] = None
                                    res.xtra["DHBM"] = None
                                    res.xtra["DHCM"] = None
                                    res.xtra["DHDM"] = None
                                    res.xtra["DHEM"] = None
                                    res.xtra["DHFM"] = None
                                    res.xtra["DHAS"] = None
                                    res.xtra["DHBS"] = None
                                    res.xtra["DHCS"] = None
                                    continue
                            try:    
                                dhem = calc_dihedral(c4dp, c3dp, o3dp, p)
                            except:
                                dhem = None
                            try:
                                dhfm = calc_dihedral(c3dp, o3dp, p, o5d)
                            except:
                                dhfm = None
                            try:
                                dham = calc_dihedral(o3dp, p, o5d, c5d)
                            except:
                                dham = None
                            try:
                                dhbm = calc_dihedral(p, o5d, c5d, c4d)
                            except:
                                dhbm = None
                            try:
                                dhcm = calc_dihedral(o5d, c5d, c4d, o4d)
                            except:
                                dhcm = None
                            try:
                                dhdm = calc_dihedral(o4d, c4d, c3d, o3d)
                            except:
                                dhdm = None
                            try:
                                dhas = calc_dihedral(c1d, c2d, o2d, oh)
                            except:
                                dhas = None
                            try:
                                dhbs = calc_dihedral(o4d, c1d, n9, c8)
                            except:
                                dhbs = None
                            try:
                                dhcs = calc_dihedral(n3, c2, n2, nh)
                            except:
                                dhcs = None
                            ppl.append((dham, dhbm, dhcm, dhdm, dhem, dhfm, dhas, dhbs, dhcs))
                            # Add dihedral to xtra dict of residue
                            res.xtra["DHAM"] = dham
                            res.xtra["DHBM"] = dhbm
                            res.xtra["DHCM"] = dhcm
                            res.xtra["DHDM"] = dhdm
                            res.xtra["DHEM"] = dhem
                            res.xtra["DHFM"] = dhfm
                            res.xtra["DHAS"] = dhas
                            res.xtra["DHBS"] = dhbs
                            res.xtra["DHCS"] = dhcs
                            # translate dihedral to ConfCode
                            ccem = conf_code_al(dhem)
                            ccfm = conf_code_al(dhfm)
                            ccam = conf_code_al(dham)
                            ccbm = conf_code_al(dhbm)
                            cccm = conf_code_al(dhcm)
                            ccdm = conf_code_al(dhdm)
                            ccas = conf_code_al(dhas)
                            ccbs = conf_code_al(dhbs)
                            cccs = conf_code_al(dhcs)
                            ccem_st = "%s" % (ccem)
                            ccfm_st = "%s" % (ccfm)
                            ccam_st = "%s" % (ccam)
                            ccbm_st = "%s" % (ccbm)
                            cccm_st = "%s" % (cccm)
                            ccdm_st = "%s" % (ccdm)
                            ccas_st = "%s" % (ccas)
                            ccbs_st = "%s" % (ccbs)
                            cccs_st = "%s" % (cccs)
                            # SSC for RNA
                            lem = '6a'
                            lfm = '3a'
                            lam = '3a'
                            lbm = '1a'
                            lcm = '3a'
                            ldm = '6a'
                            mem = '6a'
                            mfm = '3a'
                            mam = '5c'
                            mbm = '1a'
                            mcm = '2c'
                            mdm = '6a'
                            #nem = '6a'
                            #nfm = '3a'
                            #nam = '5c'
                            #nbm = '1a'
                            #ncm = '3a'
                            #ndm = '6a'
                            #pem = '6a'
                            #pfm = '3a'
                            #pam = '3a'
                            #pbm = '1a'
                            #pcm = '2c'
                            #pdm = '6a'
                            #qem = '6a'
                            #qfm = '5c'
                            #qam = '3a'
                            #qbm = '1a'
                            #qcm = '3a'
                            #qdm = '6a'
                            #rem = '6a'
                            #rfm = '5c'
                            #am = '5c'
                            #bm = '1a'
                            #cm = '3a'
                            #dm = '6a'
                            #vem = '6a'
                            #vfm = '5c'
                            #vam = '3a'
                            #vbm = '1a'
                            #vcm = '2c'
                            #vdm = '6a'
                            #wem = '6a'
                            #wfm = '5c'
                            #wam = '5c'
                            #wbm = '1a'
                            #wcm = '2c'
                            #wdm = '6a'
                            try:
                                j_lem = _test_homology_al(ccem_st, lem)
                                j_mem = _test_homology_al(ccem_st, mem)
                                #j_nem = _test_homology_al(ccem_st, nem)
                                #j_pem = _test_homology_al(ccem_st, pem)
                                #j_qem = _test_homology_al(ccem_st, qem)
                                #j_rem = _test_homology_al(ccem_st, rem)
                                #j_vem = _test_homology_al(ccem_st, vem)
                                #j_wem = _test_homology_al(ccem_st, wem)
                                j_lfm = _test_homology_al(ccfm_st, lfm)
                                j_mfm = _test_homology_al(ccfm_st, mfm)
                                #j_nfm = _test_homology_al(ccfm_st, nfm)
                                #j_pfm = _test_homology_al(ccfm_st, pfm)
                                #j_qfm = _test_homology_al(ccfm_st, qfm)
                                #j_rfm = _test_homology_al(ccfm_st, rfm)
                                #j_vfm = _test_homology_al(ccfm_st, vfm)
                                #j_wfm = _test_homology_al(ccfm_st, wfm)
                                j_lam = _test_homology_al(ccam_st, lam)
                                j_mam = _test_homology_al(ccam_st, mam)
                                #j_nam = _test_homology_al(ccam_st, nam)
                                #j_pam = _test_homology_al(ccam_st, pam)
                                #j_qam = _test_homology_al(ccam_st, qam)
                                #j_ram = _test_homology_al(ccam_st, ram)
                                #j_vam = _test_homology_al(ccam_st, vam)
                                #j_wam = _test_homology_al(ccam_st, wam)
                                j_lbm = _test_homology_al(ccbm_st, lbm)
                                j_mbm = _test_homology_al(ccbm_st, mbm)
                                #j_nbm = _test_homology_al(ccbm_st, nbm)
                                #j_pbm = _test_homology_al(ccbm_st, pbm)
                                #j_qbm = _test_homology_al(ccbm_st, qbm)
                                #j_rbm = _test_homology_al(ccbm_st, rbm)
                                #j_vbm = _test_homology_al(ccbm_st, vbm)
                                #j_wbm = _test_homology_al(ccbm_st, wbm)
                                j_lcm = _test_homology_al(cccm_st, lcm)
                                j_mcm = _test_homology_al(cccm_st, mcm)
                                #j_ncm = _test_homology_al(cccm_st, ncm)
                                #j_pcm = _test_homology_al(cccm_st, pcm)
                                #j_qcm = _test_homology_al(cccm_st, qcm)
                                #j_rcm = _test_homology_al(cccm_st, rcm)
                                #j_vcm = _test_homology_al(cccm_st, vcm)
                                #j_wcm = _test_homology_al(cccm_st, wcm)
                                j_ldm = _test_homology_al(ccdm_st, ldm)
                                j_mdm = _test_homology_al(ccdm_st, mdm)
                                #j_ndm = _test_homology_al(ccdm_st, ndm)
                                #j_pdm = _test_homology_al(ccdm_st, pdm)
                                #j_qdm = _test_homology_al(ccdm_st, qdm)
                                #j_rdm = _test_homology_al(ccdm_st, rdm)
                                #j_vdm = _test_homology_al(ccdm_st, vdm)
                                #j_wdm = _test_homology_al(ccdm_st, wdm)
                                lc_l_mchain = j_lem*j_lfm*j_lam*j_lbm*j_lcm*j_ldm
                                lc_m_mchain = j_mem*j_mfm*j_mam*j_mbm*j_mcm*j_mdm
                                #lc_n_mchain = j_nem*j_nfm*j_nam*j_nbm*j_ncm*j_ndm
                                #lc_p_mchain = j_pem*j_pfm*j_pam*j_pbm*j_pcm*j_pdm
                                #lc_q_mchain = j_qem*j_qfm*j_qam*j_qbm*j_qcm*j_qdm
                                #lc_r_mchain = j_rem*j_rfm*j_ram*j_rbm*j_rcm*j_rdm
                                #lc_v_mchain = j_vem*j_vfm*j_vam*j_vbm*j_vcm*j_vdm
                                #lc_w_mchain = j_wem*j_wfm*j_wam*j_wbm*j_wcm*j_wdm
                                ssc_st = ""
                                if lc_l_mchain == 1 :
                                    ssc_st = "P"
                                elif lc_m_mchain == 1 :
                                    ssc_st = "S"
                                #elif lc_n_mchain == 1 :
                                    #ssc_st = "N"
                                #elif lc_p_mchain == 1 :
                                    #ssc_st = "P"
                                #elif lc_q_mchain == 1 :
                                    #ssc_st = "Q"
                                #elif lc_r_mchain == 1 :
                                    #ssc_st = "R"
                                #elif lc_v_mchain == 1 :
                                    #ssc_st = "V"
                                #elif lc_w_mchain == 1 :
                                    #ssc_st = "W"
                                else :
                                    ssc_st = "T"
                            except:
                                ssc_st = "D"
                            res_name = "%s%i" % (residue_name, residue_num)
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            fc.write('\t')
                            fc.write(ssc_st)                        
                            fc.write('\t')                            
                            fc.write(ccem_st)
                            fc.write('\t')
                            fc.write(ccfm_st)
                            fc.write('\t')
                            fc.write(ccam_st)
                            fc.write('\t')
                            fc.write(ccbm_st)
                            fc.write('\t')
                            fc.write(cccm_st)
                            fc.write('\t')
                            fc.write(ccdm_st)
                            fc.write('\t')
                            fc.write(ccas_st)
                            fc.write('\t')
                            fc.write(ccbs_st)
                            fc.write('\t')
                            fc.write(cccs_st)
                            fc.write('\n')
                            fc.close()
                            try:
                                c4dp = c4d
                                c3dp = c3d
                                o3dp = o3d
                                p = []
                                o5d = []
                                c5d = [] 
                                c4d = []
                                o4d = []
                                c3d = []
                                o3d = []
                                c2d = []
                                o2d = []
                                c1d = []
                                oh = []
                                n9 = []
                                c8 = []
                                c6 = []
                                n6 = []
                                n1 = []
                                nh = []
                                c2 = []
                                n2 = [] 
                                n3 = []
                                c4 = []
                                n4 = []                             
                            except:
                                continue

                        # C
                        elif residue_name == "C" :
                            for atom_index, atom in enumerate(residue) :
                                atom_id = atom.id
                                res = atom
                                try:
                                    if atom_id == "P" :
                                        p = atom.get_vector()
                                    elif atom_id == "O5'" :
                                        o5d = atom.get_vector()
                                    elif atom_id == "C5'" :
                                        c5d = atom.get_vector()
                                    elif atom_id == "C4'" :
                                        c4d = atom.get_vector()
                                    elif atom_id == "O4'" :
                                        o4d = atom.get_vector()
                                    elif atom_id == "C3'" :
                                        c3d = atom.get_vector()
                                    elif atom_id == "O3'" :
                                        o3d = atom.get_vector()
                                    elif atom_id == "C2'" :
                                        c2d = atom.get_vector()
                                    elif atom_id == "O2'" :
                                        o2d = atom.get_vector()
                                    elif atom_id == "C1'" :
                                        c1d = atom.get_vector()
                                    elif atom_id == "OH" :
                                        oh = atom.get_vector()
                                    elif atom_id == "N1" :
                                        n1 = atom.get_vector()
                                    elif atom_id == "C2" :
                                        c2 = atom.get_vector()
                                    elif atom_id == "N3" :
                                        n3 = atom.get_vector()
                                    elif atom_id == "C4" :
                                        c4 = atom.get_vector()
                                    elif atom_id == "N4" :
                                        n4 = atom.get_vector()
                                    elif atom_id == "NH" :
                                        nh = atom.get_vector()
                                except:
                                    # Some atoms are missing
                                    # dihedral cannot be calculated for this residue
                                    ppl.append((None, None, None, None, None, None, None, None, None))
                                    res.xtra["DHAM"] = None
                                    res.xtra["DHBM"] = None
                                    res.xtra["DHCM"] = None
                                    res.xtra["DHDM"] = None
                                    res.xtra["DHEM"] = None
                                    res.xtra["DHFM"] = None
                                    res.xtra["DHAS"] = None
                                    res.xtra["DHBS"] = None
                                    res.xtra["DHCS"] = None
                                    continue
                            try:    
                                dhem = calc_dihedral(c4dp, c3dp, o3dp, p)
                            except:
                                dhem = None
                            try:
                                dhfm = calc_dihedral(c3dp, o3dp, p, o5d)
                            except:
                                dhfm = None
                            try:
                                dham = calc_dihedral(o3dp, p, o5d, c5d)
                            except:
                                dham = None
                            try:
                                dhbm = calc_dihedral(p, o5d, c5d, c4d)
                            except:
                                dhbm = None
                            try:
                                dhcm = calc_dihedral(o5d, c5d, c4d, o4d)
                            except:
                                dhcm = None
                            try:
                                dhdm = calc_dihedral(o4d, c4d, c3d, o3d)
                            except:
                                dhdm = None
                            try:
                                dhas = calc_dihedral(c1d, c2d, o2d, oh)
                            except:
                                dhas = None
                            try:
                                dhbs = calc_dihedral(o4d, c1d, n1, c2)
                            except:
                                dhbs = None
                            try:
                                dhcs = calc_dihedral(n3, c4, n4, nh)
                            except:
                                dhcs = None
                            ppl.append((dham, dhbm, dhcm, dhdm, dhem, dhfm, dhas, dhbs, dhcs))
                            # Add dihedral to xtra dict of residue
                            res.xtra["DHAM"] = dham
                            res.xtra["DHBM"] = dhbm
                            res.xtra["DHCM"] = dhcm
                            res.xtra["DHDM"] = dhdm
                            res.xtra["DHEM"] = dhem
                            res.xtra["DHFM"] = dhfm
                            res.xtra["DHAS"] = dhas
                            res.xtra["DHBS"] = dhbs
                            res.xtra["DHCS"] = dhcs
                            # translate dihedral to ConfCode
                            ccem = conf_code_al(dhem)
                            ccfm = conf_code_al(dhfm)
                            ccam = conf_code_al(dham)
                            ccbm = conf_code_al(dhbm)
                            cccm = conf_code_al(dhcm)
                            ccdm = conf_code_al(dhdm)
                            ccas = conf_code_al(dhas)
                            ccbs = conf_code_al(dhbs)
                            cccs = conf_code_al(dhcs)
                            ccem_st = "%s" % (ccem)
                            ccfm_st = "%s" % (ccfm)
                            ccam_st = "%s" % (ccam)
                            ccbm_st = "%s" % (ccbm)
                            cccm_st = "%s" % (cccm)
                            ccdm_st = "%s" % (ccdm)
                            ccas_st = "%s" % (ccas)
                            ccbs_st = "%s" % (ccbs)
                            cccs_st = "%s" % (cccs)
                            # SSC for RNA
                            lem = '6a'
                            lfm = '3a'
                            lam = '3a'
                            lbm = '1a'
                            lcm = '3a'
                            ldm = '6a'
                            mem = '6a'
                            mfm = '3a'
                            mam = '5c'
                            mbm = '1a'
                            mcm = '2c'
                            mdm = '6a'
                            #nem = '6a'
                            #nfm = '3a'
                            #nam = '5c'
                            #nbm = '1a'
                            #ncm = '3a'
                            #ndm = '6a'
                            #pem = '6a'
                            #pfm = '3a'
                            #pam = '3a'
                            #pbm = '1a'
                            #pcm = '2c'
                            #pdm = '6a'
                            #qem = '6a'
                            #qfm = '5c'
                            #qam = '3a'
                            #qbm = '1a'
                            #qcm = '3a'
                            #qdm = '6a'
                            #rem = '6a'
                            #rfm = '5c'
                            #am = '5c'
                            #bm = '1a'
                            #cm = '3a'
                            #dm = '6a'
                            #vem = '6a'
                            #vfm = '5c'
                            #vam = '3a'
                            #vbm = '1a'
                            #vcm = '2c'
                            #vdm = '6a'
                            #wem = '6a'
                            #wfm = '5c'
                            #wam = '5c'
                            #wbm = '1a'
                            #wcm = '2c'
                            #wdm = '6a'
                            try:
                                j_lem = _test_homology_al(ccem_st, lem)
                                j_mem = _test_homology_al(ccem_st, mem)
                                #j_nem = _test_homology_al(ccem_st, nem)
                                #j_pem = _test_homology_al(ccem_st, pem)
                                #j_qem = _test_homology_al(ccem_st, qem)
                                #j_rem = _test_homology_al(ccem_st, rem)
                                #j_vem = _test_homology_al(ccem_st, vem)
                                #j_wem = _test_homology_al(ccem_st, wem)
                                j_lfm = _test_homology_al(ccfm_st, lfm)
                                j_mfm = _test_homology_al(ccfm_st, mfm)
                                #j_nfm = _test_homology_al(ccfm_st, nfm)
                                #j_pfm = _test_homology_al(ccfm_st, pfm)
                                #j_qfm = _test_homology_al(ccfm_st, qfm)
                                #j_rfm = _test_homology_al(ccfm_st, rfm)
                                #j_vfm = _test_homology_al(ccfm_st, vfm)
                                #j_wfm = _test_homology_al(ccfm_st, wfm)
                                j_lam = _test_homology_al(ccam_st, lam)
                                j_mam = _test_homology_al(ccam_st, mam)
                                #j_nam = _test_homology_al(ccam_st, nam)
                                #j_pam = _test_homology_al(ccam_st, pam)
                                #j_qam = _test_homology_al(ccam_st, qam)
                                #j_ram = _test_homology_al(ccam_st, ram)
                                #j_vam = _test_homology_al(ccam_st, vam)
                                #j_wam = _test_homology_al(ccam_st, wam)
                                j_lbm = _test_homology_al(ccbm_st, lbm)
                                j_mbm = _test_homology_al(ccbm_st, mbm)
                                #j_nbm = _test_homology_al(ccbm_st, nbm)
                                #j_pbm = _test_homology_al(ccbm_st, pbm)
                                #j_qbm = _test_homology_al(ccbm_st, qbm)
                                #j_rbm = _test_homology_al(ccbm_st, rbm)
                                #j_vbm = _test_homology_al(ccbm_st, vbm)
                                #j_wbm = _test_homology_al(ccbm_st, wbm)
                                j_lcm = _test_homology_al(cccm_st, lcm)
                                j_mcm = _test_homology_al(cccm_st, mcm)
                                #j_ncm = _test_homology_al(cccm_st, ncm)
                                #j_pcm = _test_homology_al(cccm_st, pcm)
                                #j_qcm = _test_homology_al(cccm_st, qcm)
                                #j_rcm = _test_homology_al(cccm_st, rcm)
                                #j_vcm = _test_homology_al(cccm_st, vcm)
                                #j_wcm = _test_homology_al(cccm_st, wcm)
                                j_ldm = _test_homology_al(ccdm_st, ldm)
                                j_mdm = _test_homology_al(ccdm_st, mdm)
                                #j_ndm = _test_homology_al(ccdm_st, ndm)
                                #j_pdm = _test_homology_al(ccdm_st, pdm)
                                #j_qdm = _test_homology_al(ccdm_st, qdm)
                                #j_rdm = _test_homology_al(ccdm_st, rdm)
                                #j_vdm = _test_homology_al(ccdm_st, vdm)
                                #j_wdm = _test_homology_al(ccdm_st, wdm)
                                lc_l_mchain = j_lem*j_lfm*j_lam*j_lbm*j_lcm*j_ldm
                                lc_m_mchain = j_mem*j_mfm*j_mam*j_mbm*j_mcm*j_mdm
                                #lc_n_mchain = j_nem*j_nfm*j_nam*j_nbm*j_ncm*j_ndm
                                #lc_p_mchain = j_pem*j_pfm*j_pam*j_pbm*j_pcm*j_pdm
                                #lc_q_mchain = j_qem*j_qfm*j_qam*j_qbm*j_qcm*j_qdm
                                #lc_r_mchain = j_rem*j_rfm*j_ram*j_rbm*j_rcm*j_rdm
                                #lc_v_mchain = j_vem*j_vfm*j_vam*j_vbm*j_vcm*j_vdm
                                #lc_w_mchain = j_wem*j_wfm*j_wam*j_wbm*j_wcm*j_wdm
                                ssc_st = ""
                                if lc_l_mchain == 1 :
                                    ssc_st = "P"
                                elif lc_m_mchain == 1 :
                                    ssc_st = "S"
                                #elif lc_n_mchain == 1 :
                                    #ssc_st = "N"
                                #elif lc_p_mchain == 1 :
                                    #ssc_st = "P"
                                #elif lc_q_mchain == 1 :
                                    #ssc_st = "Q"
                                #elif lc_r_mchain == 1 :
                                    #ssc_st = "R"
                                #elif lc_v_mchain == 1 :
                                    #ssc_st = "V"
                                #elif lc_w_mchain == 1 :
                                    #ssc_st = "W"
                                else :
                                    ssc_st = "T"
                            except:
                                ssc_st = "D"
                            res_name = "%s%i" % (residue_name, residue_num)
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            fc.write('\t')
                            fc.write(ssc_st)                        
                            fc.write('\t')                            
                            fc.write(ccem_st)
                            fc.write('\t')
                            fc.write(ccfm_st)
                            fc.write('\t')
                            fc.write(ccam_st)
                            fc.write('\t')
                            fc.write(ccbm_st)
                            fc.write('\t')
                            fc.write(cccm_st)
                            fc.write('\t')
                            fc.write(ccdm_st)
                            fc.write('\t')
                            fc.write(ccas_st)
                            fc.write('\t')
                            fc.write(ccbs_st)
                            fc.write('\t')
                            fc.write(cccs_st)
                            fc.write('\n')
                            fc.close()
                            try:
                                c4dp = c4d
                                c3dp = c3d
                                o3dp = o3d
                                p = []
                                o5d = []
                                c5d = [] 
                                c4d = []
                                o4d = []
                                c3d = []
                                o3d = []
                                c2d = []
                                o2d = []
                                c1d = []
                                oh = []
                                n9 = []
                                c8 = []
                                c6 = []
                                n6 = []
                                n1 = []
                                nh = []
                                c2 = []
                                n2 = [] 
                                n3 = []
                                c4 = []
                                n4 = []                             
                            except:
                                continue

                        # U
                        elif residue_name == "U" :
                            for atom_index, atom in enumerate(residue) :
                                atom_id = atom.id
                                res = atom
                                try:
                                    if atom_id == "P" :
                                        p = atom.get_vector()
                                    elif atom_id == "O5'" :
                                        o5d = atom.get_vector()
                                    elif atom_id == "C5'" :
                                        c5d = atom.get_vector()
                                    elif atom_id == "C4'" :
                                        c4d = atom.get_vector()
                                    elif atom_id == "O4'" :
                                        o4d = atom.get_vector()
                                    elif atom_id == "C3'" :
                                        c3d = atom.get_vector()
                                    elif atom_id == "O3'" :
                                        o3d = atom.get_vector()
                                    elif atom_id == "C2'" :
                                        c2d = atom.get_vector()
                                    elif atom_id == "O2'" :
                                        o2d = atom.get_vector()
                                    elif atom_id == "C1'" :
                                        c1d = atom.get_vector()
                                    elif atom_id == "OH" :
                                        oh = atom.get_vector()
                                    elif atom_id == "N1" :
                                        n1 = atom.get_vector()
                                    elif atom_id == "C2" :
                                        c2 = atom.get_vector()
                                except:
                                    # Some atoms are missing
                                    # dihedral cannot be calculated for this residue
                                    ppl.append((None, None, None, None, None, None, None, None, None))
                                    res.xtra["DHAM"] = None
                                    res.xtra["DHBM"] = None
                                    res.xtra["DHCM"] = None
                                    res.xtra["DHDM"] = None
                                    res.xtra["DHEM"] = None
                                    res.xtra["DHFM"] = None
                                    res.xtra["DHAS"] = None
                                    res.xtra["DHBS"] = None
                                    res.xtra["DHCS"] = None
                                    continue
                            try:    
                                dhem = calc_dihedral(c4dp, c3dp, o3dp, p)
                            except:
                                dhem = None
                            try:
                                dhfm = calc_dihedral(c3dp, o3dp, p, o5d)
                            except:
                                dhfm = None
                            try:
                                dham = calc_dihedral(o3dp, p, o5d, c5d)
                            except:
                                dham = None
                            try:
                                dhbm = calc_dihedral(p, o5d, c5d, c4d)
                            except:
                                dhbm = None
                            try:
                                dhcm = calc_dihedral(o5d, c5d, c4d, o4d)
                            except:
                                dhcm = None
                            try:
                                dhdm = calc_dihedral(o4d, c4d, c3d, o3d)
                            except:
                                dhdm = None
                            try:
                                dhas = calc_dihedral(c1d, c2d, o2d, oh)
                            except:
                                dhas = None
                            try:
                                dhbs = calc_dihedral(o4d, c1d, n1, c2)
                            except:
                                dhbs = None
                            dhcs = None
                            ppl.append((dham, dhbm, dhcm, dhdm, dhem, dhfm, dhas, dhbs, dhcs))                    
                            # Add dihedral to xtra dict of residue
                            res.xtra["DHAM"] = dham
                            res.xtra["DHBM"] = dhbm
                            res.xtra["DHCM"] = dhcm
                            res.xtra["DHDM"] = dhdm
                            res.xtra["DHEM"] = dhem
                            res.xtra["DHFM"] = dhfm
                            res.xtra["DHAS"] = dhas
                            res.xtra["DHBS"] = dhbs
                            res.xtra["DHCS"] = dhcs
                            # translate dihedral to ConfCode
                            ccem = conf_code_al(dhem)
                            ccfm = conf_code_al(dhfm)
                            ccam = conf_code_al(dham)
                            ccbm = conf_code_al(dhbm)
                            cccm = conf_code_al(dhcm)
                            ccdm = conf_code_al(dhdm)
                            ccas = conf_code_al(dhas)
                            ccbs = conf_code_al(dhbs)
                            cccs = conf_code_al(dhcs)
                            ccem_st = "%s" % (ccem)
                            ccfm_st = "%s" % (ccfm)
                            ccam_st = "%s" % (ccam)
                            ccbm_st = "%s" % (ccbm)
                            cccm_st = "%s" % (cccm)
                            ccdm_st = "%s" % (ccdm)
                            ccas_st = "%s" % (ccas)
                            ccbs_st = "%s" % (ccbs)
                            cccs_st = "%s" % (cccs)
                            # SSC for RNA
                            lem = '6a'
                            lfm = '3a'
                            lam = '3a'
                            lbm = '1a'
                            lcm = '3a'
                            ldm = '6a'
                            mem = '6a'
                            mfm = '3a'
                            mam = '5c'
                            mbm = '1a'
                            mcm = '2c'
                            mdm = '6a'
                            #nem = '6a'
                            #nfm = '3a'
                            #nam = '5c'
                            #nbm = '1a'
                            #ncm = '3a'
                            #ndm = '6a'
                            #pem = '6a'
                            #pfm = '3a'
                            #pam = '3a'
                            #pbm = '1a'
                            #pcm = '2c'
                            #pdm = '6a'
                            #qem = '6a'
                            #qfm = '5c'
                            #qam = '3a'
                            #qbm = '1a'
                            #qcm = '3a'
                            #qdm = '6a'
                            #rem = '6a'
                            #rfm = '5c'
                            #am = '5c'
                            #bm = '1a'
                            #cm = '3a'
                            #dm = '6a'
                            #vem = '6a'
                            #vfm = '5c'
                            #vam = '3a'
                            #vbm = '1a'
                            #vcm = '2c'
                            #vdm = '6a'
                            #wem = '6a'
                            #wfm = '5c'
                            #wam = '5c'
                            #wbm = '1a'
                            #wcm = '2c'
                            #wdm = '6a'
                            try:
                                j_lem = _test_homology_al(ccem_st, lem)
                                j_mem = _test_homology_al(ccem_st, mem)
                                #j_nem = _test_homology_al(ccem_st, nem)
                                #j_pem = _test_homology_al(ccem_st, pem)
                                #j_qem = _test_homology_al(ccem_st, qem)
                                #j_rem = _test_homology_al(ccem_st, rem)
                                #j_vem = _test_homology_al(ccem_st, vem)
                                #j_wem = _test_homology_al(ccem_st, wem)
                                j_lfm = _test_homology_al(ccfm_st, lfm)
                                j_mfm = _test_homology_al(ccfm_st, mfm)
                                #j_nfm = _test_homology_al(ccfm_st, nfm)
                                #j_pfm = _test_homology_al(ccfm_st, pfm)
                                #j_qfm = _test_homology_al(ccfm_st, qfm)
                                #j_rfm = _test_homology_al(ccfm_st, rfm)
                                #j_vfm = _test_homology_al(ccfm_st, vfm)
                                #j_wfm = _test_homology_al(ccfm_st, wfm)
                                j_lam = _test_homology_al(ccam_st, lam)
                                j_mam = _test_homology_al(ccam_st, mam)
                                #j_nam = _test_homology_al(ccam_st, nam)
                                #j_pam = _test_homology_al(ccam_st, pam)
                                #j_qam = _test_homology_al(ccam_st, qam)
                                #j_ram = _test_homology_al(ccam_st, ram)
                                #j_vam = _test_homology_al(ccam_st, vam)
                                #j_wam = _test_homology_al(ccam_st, wam)
                                j_lbm = _test_homology_al(ccbm_st, lbm)
                                j_mbm = _test_homology_al(ccbm_st, mbm)
                                #j_nbm = _test_homology_al(ccbm_st, nbm)
                                #j_pbm = _test_homology_al(ccbm_st, pbm)
                                #j_qbm = _test_homology_al(ccbm_st, qbm)
                                #j_rbm = _test_homology_al(ccbm_st, rbm)
                                #j_vbm = _test_homology_al(ccbm_st, vbm)
                                #j_wbm = _test_homology_al(ccbm_st, wbm)
                                j_lcm = _test_homology_al(cccm_st, lcm)
                                j_mcm = _test_homology_al(cccm_st, mcm)
                                #j_ncm = _test_homology_al(cccm_st, ncm)
                                #j_pcm = _test_homology_al(cccm_st, pcm)
                                #j_qcm = _test_homology_al(cccm_st, qcm)
                                #j_rcm = _test_homology_al(cccm_st, rcm)
                                #j_vcm = _test_homology_al(cccm_st, vcm)
                                #j_wcm = _test_homology_al(cccm_st, wcm)
                                j_ldm = _test_homology_al(ccdm_st, ldm)
                                j_mdm = _test_homology_al(ccdm_st, mdm)
                                #j_ndm = _test_homology_al(ccdm_st, ndm)
                                #j_pdm = _test_homology_al(ccdm_st, pdm)
                                #j_qdm = _test_homology_al(ccdm_st, qdm)
                                #j_rdm = _test_homology_al(ccdm_st, rdm)
                                #j_vdm = _test_homology_al(ccdm_st, vdm)
                                #j_wdm = _test_homology_al(ccdm_st, wdm)
                                lc_l_mchain = j_lem*j_lfm*j_lam*j_lbm*j_lcm*j_ldm
                                lc_m_mchain = j_mem*j_mfm*j_mam*j_mbm*j_mcm*j_mdm
                                #lc_n_mchain = j_nem*j_nfm*j_nam*j_nbm*j_ncm*j_ndm
                                #lc_p_mchain = j_pem*j_pfm*j_pam*j_pbm*j_pcm*j_pdm
                                #lc_q_mchain = j_qem*j_qfm*j_qam*j_qbm*j_qcm*j_qdm
                                #lc_r_mchain = j_rem*j_rfm*j_ram*j_rbm*j_rcm*j_rdm
                                #lc_v_mchain = j_vem*j_vfm*j_vam*j_vbm*j_vcm*j_vdm
                                #lc_w_mchain = j_wem*j_wfm*j_wam*j_wbm*j_wcm*j_wdm
                                ssc_st = ""
                                if lc_l_mchain == 1 :
                                    ssc_st = "P"
                                elif lc_m_mchain == 1 :
                                    ssc_st = "S"
                                #elif lc_n_mchain == 1 :
                                    #ssc_st = "N"
                                #elif lc_p_mchain == 1 :
                                    #ssc_st = "P"
                                #elif lc_q_mchain == 1 :
                                    #ssc_st = "Q"
                                #elif lc_r_mchain == 1 :
                                    #ssc_st = "R"
                                #elif lc_v_mchain == 1 :
                                    #ssc_st = "V"
                                #elif lc_w_mchain == 1 :
                                    #ssc_st = "W"
                                else :
                                    ssc_st = "T"
                            except:
                                ssc_st = "D"
                            res_name = "%s%i" % (residue_name, residue_num)
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            fc.write('\t')
                            fc.write(ssc_st)                        
                            fc.write('\t')                            
                            fc.write(ccem_st)
                            fc.write('\t')
                            fc.write(ccfm_st)
                            fc.write('\t')
                            fc.write(ccam_st)
                            fc.write('\t')
                            fc.write(ccbm_st)
                            fc.write('\t')
                            fc.write(cccm_st)
                            fc.write('\t')
                            fc.write(ccdm_st)
                            fc.write('\t')
                            fc.write(ccas_st)
                            fc.write('\t')
                            fc.write(ccbs_st)
                            fc.write('\t')
                            fc.write(cccs_st)
                            fc.write('\n')
                            fc.close()
                            try:
                                c4dp = c4d
                                c3dp = c3d
                                o3dp = o3d
                                p = []
                                o5d = []
                                c5d = [] 
                                c4d = []
                                o4d = []
                                c3d = []
                                o3d = []
                                c2d = []
                                o2d = []
                                c1d = []
                                oh = []
                                n9 = []
                                c8 = []
                                c6 = []
                                n6 = []
                                n1 = []
                                nh = []
                                c2 = []
                                n2 = [] 
                                n3 = []
                                c4 = []
                                n4 = []                             
                            except:
                                continue

                        else:
                            continue
                else:
                    if residue_index == 0:
                        #break
                        fc = open(str(fname), 'w')
                        fc.write('')
                        mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                        mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                        mname3 = "length %i " % (len(residue))
                        fc.write(str(mname1))
                        fc.write('\n')
                        fc.close()

flist = os.listdir("C:/SSCRview/SSCR_data")

os.chdir("C:/SSCRview/SSCR_data")
for i, line in enumerate(flist):
    fa = open(str(line), 'r')
    dataa1 = fa.readlines()
    fa.close()
    try:
        dataa1[1]
    except:
        os.remove(str(str(line)))
        
    
flist = os.listdir("C:/SSCRview/PDB_MMCIF_GZ")
one_letter ={'  A':'A', '  G':'G', '  C':'C', '  U':'U'}

for i, pdb_file_gz in enumerate(flist):
    os.chdir("C:/SSCRview/PDB_MMCIF_GZ")
    pdb_file = _open(pdb_file_gz)
    for model in Bio.PDB.FastMMCIFParser().get_structure("RNA", pdb_file) :
        for chain in model :
            full_id=model.get_full_id()
            #mname = pdb_file[-8:-4]
            mname = pdb_file_gz[:-7]
            fname = "C:/SSCRview/SSCR_ssc_data/%s_Model_%s_Chain_%s.txt" % (str(mname), str(model.id), str(chain.id))
            c4dp = []
            c3dp = []
            o3dp = []
            for residue_index, residue in enumerate(chain) :
                residue_id = residue.id
                residue_num = residue_id[1]
                residue_name = residue.resname
                #if residue_name == "A" or residue_name == "G" or residue_name == "C" or residue_name == "U" :
                if residue_index == 0:
                    ppl=[]
                    fc = open(str(fname), 'w')
                    fc.write('')
                    mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                    mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                    mname3 = "length %i " % (len(residue))
                    fc.write(str(mname1))
                    fc.write('\n')
                    re_nump = 0
                    for re_index, re in enumerate(chain) :
                        re_name = re.resname
                        re_id = re.id
                        re_num = re_id[1]
                        if re_name == "A" or re_name == "G" or re_name == "C" or re_name == "U" :
                            re_name1 = "%s" % (re_name)
                            #re_name2 = "%s" % (one_letter[re_name1])
                            fc.write('')
                            if re_index > 0:
                                if re_num != re_nump + 1:
                                    fc.write("X")
                                    #print (re_num)
                                    #print (re_nump)
                            re_nump = re_num
                            fc.write(re_name1)
                        else:
                            continue
                            
                    if re_index == len(chain) - 1:    
                        fc.write('\n')
                    else:
                        continue
                    fc.close()
                else:
                    continue
                                            
            residue_nump = 0
            for residue_index, residue in enumerate(chain) :
                residue_id = residue.id
                residue_num = residue_id[1]
                residue_name = residue.resname
                if residue_name == "A" or residue_name == "G" or residue_name == "C" or residue_name == "U" :
                    ppl=[]
                    fc = open(str(fname), 'a')
                    fc.write('')
                    mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                    mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                    mname3 = "length %i " % (len(residue))
                    for atom_index, atom in enumerate(residue) :
                        atom_id = atom.id
                        res = atom
                        try:
                            if atom_id == "P" :
                                p = atom.get_vector()
                            elif atom_id == "O5'" :
                                o5d = atom.get_vector()
                            elif atom_id == "C5'" :
                                c5d = atom.get_vector()
                            elif atom_id == "C4'" :
                                c4d = atom.get_vector()
                            elif atom_id == "O4'" :
                                o4d = atom.get_vector()
                            elif atom_id == "C3'" :
                                c3d = atom.get_vector()
                            elif atom_id == "O3'" :
                                o3d = atom.get_vector()
                            elif atom_id == "C2'" :
                                c2d = atom.get_vector()
                            elif atom_id == "O2'" :
                                o2d = atom.get_vector()
                            elif atom_id == "C1'" :
                                c1d = atom.get_vector()
                            elif atom_id == "OH" :
                                oh = atom.get_vector()
                        except:
                            # Some atoms are missing
                            # dihedral cannot be calculated for this residue
                            ppl.append((None, None, None, None, None, None, None, None, None))
                            res.xtra["DHAM"] = None
                            res.xtra["DHBM"] = None
                            res.xtra["DHCM"] = None
                            res.xtra["DHDM"] = None
                            res.xtra["DHEM"] = None
                            res.xtra["DHFM"] = None
                            res.xtra["DHAS"] = None
                            res.xtra["DHBS"] = None
                            res.xtra["DHCS"] = None
                            continue
                    try:    
                        dhem = calc_dihedral(c4dp, c3dp, o3dp, p)
                    except:
                        dhem = None
                    try:
                        dhfm = calc_dihedral(c3dp, o3dp, p, o5d)
                    except:
                        dhfm = None
                    try:
                        dham = calc_dihedral(o3dp, p, o5d, c5d)
                    except:
                        dham = None
                    try:
                        dhbm = calc_dihedral(p, o5d, c5d, c4d)
                    except:
                        dhbm = None
                    try:
                        dhcm = calc_dihedral(o5d, c5d, c4d, o4d)
                    except:
                        dhcm = None
                    try:
                        dhdm = calc_dihedral(o4d, c4d, c3d, o3d)
                    except:
                        dhdm = None
                    try:
                        dhas = calc_dihedral(c1d, c2d, o2d, oh)
                    except:
                        dhas = None                        
                    dhbs = None                            
                    dhcs = None
                    ppl.append((dham, dhbm, dhcm, dhdm, dhem, dhfm, dhas, dhbs, dhcs))
                    # Add dihedral to xtra dict of residue
                    res.xtra["DHAM"] = dham
                    res.xtra["DHBM"] = dhbm
                    res.xtra["DHCM"] = dhcm
                    res.xtra["DHDM"] = dhdm
                    res.xtra["DHEM"] = dhem
                    res.xtra["DHFM"] = dhfm
                    res.xtra["DHAS"] = dhas
                    res.xtra["DHBS"] = dhbs
                    res.xtra["DHCS"] = dhcs
                    # translate dihedral to ConfCode
                    ccem = conf_code_al(dhem)
                    ccfm = conf_code_al(dhfm)
                    ccam = conf_code_al(dham)
                    ccbm = conf_code_al(dhbm)
                    cccm = conf_code_al(dhcm)
                    ccdm = conf_code_al(dhdm)
                    ccas = conf_code_al(dhas)
                    ccbs = conf_code_al(dhbs)
                    cccs = conf_code_al(dhcs)
                    ccem_st = "%s" % (ccem)
                    ccfm_st = "%s" % (ccfm)
                    ccam_st = "%s" % (ccam)
                    ccbm_st = "%s" % (ccbm)
                    cccm_st = "%s" % (cccm)
                    ccdm_st = "%s" % (ccdm)
                    ccas_st = "%s" % (ccas)
                    ccbs_st = "%s" % (ccbs)
                    cccs_st = "%s" % (cccs)
                    # SSC for RNA
                    lem = '6a'
                    lfm = '3a'
                    lam = '3a'
                    lbm = '1a'
                    lcm = '3a'
                    ldm = '6a'
                    mem = '6a'
                    mfm = '3a'
                    mam = '5c'
                    mbm = '1a'
                    mcm = '2c'
                    mdm = '6a'
                    #nem = '6a'
                    #nfm = '3a'
                    #nam = '5c'
                    #nbm = '1a'
                    #ncm = '3a'
                    #ndm = '6a'
                    #pem = '6a'
                    #pfm = '3a'
                    #pam = '3a'
                    #pbm = '1a'
                    #pcm = '2c'
                    #pdm = '6a'
                    #qem = '6a'
                    #qfm = '5c'
                    #qam = '3a'
                    #qbm = '1a'
                    #qcm = '3a'
                    #qdm = '6a'
                    #rem = '6a'
                    #rfm = '5c'
                    #am = '5c'
                    #bm = '1a'
                    #cm = '3a'
                    #dm = '6a'
                    #vem = '6a'
                    #vfm = '5c'
                    #vam = '3a'
                    #vbm = '1a'
                    #vcm = '2c'
                    #vdm = '6a'
                    #wem = '6a'
                    #wfm = '5c'
                    #wam = '5c'
                    #wbm = '1a'
                    #wcm = '2c'
                    #wdm = '6a'
                    try:
                        j_lem = _test_homology_al(ccem_st, lem)
                        j_mem = _test_homology_al(ccem_st, mem)
                        #j_nem = _test_homology_al(ccem_st, nem)
                        #j_pem = _test_homology_al(ccem_st, pem)
                        #j_qem = _test_homology_al(ccem_st, qem)
                        #j_rem = _test_homology_al(ccem_st, rem)
                        #j_vem = _test_homology_al(ccem_st, vem)
                        #j_wem = _test_homology_al(ccem_st, wem)
                        j_lfm = _test_homology_al(ccfm_st, lfm)
                        j_mfm = _test_homology_al(ccfm_st, mfm)
                        #j_nfm = _test_homology_al(ccfm_st, nfm)
                        #j_pfm = _test_homology_al(ccfm_st, pfm)
                        #j_qfm = _test_homology_al(ccfm_st, qfm)
                        #j_rfm = _test_homology_al(ccfm_st, rfm)
                        #j_vfm = _test_homology_al(ccfm_st, vfm)
                        #j_wfm = _test_homology_al(ccfm_st, wfm)
                        j_lam = _test_homology_al(ccam_st, lam)
                        j_mam = _test_homology_al(ccam_st, mam)
                        #j_nam = _test_homology_al(ccam_st, nam)
                        #j_pam = _test_homology_al(ccam_st, pam)
                        #j_qam = _test_homology_al(ccam_st, qam)
                        #j_ram = _test_homology_al(ccam_st, ram)
                        #j_vam = _test_homology_al(ccam_st, vam)
                        #j_wam = _test_homology_al(ccam_st, wam)
                        j_lbm = _test_homology_al(ccbm_st, lbm)
                        j_mbm = _test_homology_al(ccbm_st, mbm)
                        #j_nbm = _test_homology_al(ccbm_st, nbm)
                        #j_pbm = _test_homology_al(ccbm_st, pbm)
                        #j_qbm = _test_homology_al(ccbm_st, qbm)
                        #j_rbm = _test_homology_al(ccbm_st, rbm)
                        #j_vbm = _test_homology_al(ccbm_st, vbm)
                        #j_wbm = _test_homology_al(ccbm_st, wbm)
                        j_lcm = _test_homology_al(cccm_st, lcm)
                        j_mcm = _test_homology_al(cccm_st, mcm)
                        #j_ncm = _test_homology_al(cccm_st, ncm)
                        #j_pcm = _test_homology_al(cccm_st, pcm)
                        #j_qcm = _test_homology_al(cccm_st, qcm)
                        #j_rcm = _test_homology_al(cccm_st, rcm)
                        #j_vcm = _test_homology_al(cccm_st, vcm)
                        #j_wcm = _test_homology_al(cccm_st, wcm)
                        j_ldm = _test_homology_al(ccdm_st, ldm)
                        j_mdm = _test_homology_al(ccdm_st, mdm)
                        #j_ndm = _test_homology_al(ccdm_st, ndm)
                        #j_pdm = _test_homology_al(ccdm_st, pdm)
                        #j_qdm = _test_homology_al(ccdm_st, qdm)
                        #j_rdm = _test_homology_al(ccdm_st, rdm)
                        #j_vdm = _test_homology_al(ccdm_st, vdm)
                        #j_wdm = _test_homology_al(ccdm_st, wdm)
                        lc_l_mchain = j_lem*j_lfm*j_lam*j_lbm*j_lcm*j_ldm
                        lc_m_mchain = j_mem*j_mfm*j_mam*j_mbm*j_mcm*j_mdm
                        #lc_n_mchain = j_nem*j_nfm*j_nam*j_nbm*j_ncm*j_ndm
                        #lc_p_mchain = j_pem*j_pfm*j_pam*j_pbm*j_pcm*j_pdm
                        #lc_q_mchain = j_qem*j_qfm*j_qam*j_qbm*j_qcm*j_qdm
                        #lc_r_mchain = j_rem*j_rfm*j_ram*j_rbm*j_rcm*j_rdm
                        #lc_v_mchain = j_vem*j_vfm*j_vam*j_vbm*j_vcm*j_vdm
                        #lc_w_mchain = j_wem*j_wfm*j_wam*j_wbm*j_wcm*j_wdm
                        ssc_st = ""
                        if lc_l_mchain == 1 :
                            ssc_st = "P"
                        elif lc_m_mchain == 1 :
                            ssc_st = "S"
                        #elif lc_n_mchain == 1 :
                            #ssc_st = "N"
                        #elif lc_p_mchain == 1 :
                            #ssc_st = "P"
                        #elif lc_q_mchain == 1 :
                            #ssc_st = "Q"
                        #elif lc_r_mchain == 1 :
                            #ssc_st = "R"
                        #elif lc_v_mchain == 1 :
                            #ssc_st = "V"
                        #elif lc_w_mchain == 1 :
                            #ssc_st = "W"
                        else :
                            ssc_st = "T"
                    except:
                        ssc_st = "D"
                    res_name = "%s%i" % (residue_name, residue_num)
                    resi_name = "%s" % (residue_name)
                    resi_num = "%i" % (residue_num)
                    if residue_index > 0:
                        if residue_num != residue_nump + 1:
                            fc.write("D")                    
                    if ssc_st:
                        fc.write('')
                        fc.write(ssc_st)
                    else:
                        fc.write('D')
                    fc.close()
                    try:
                        residue_nump = residue_num
                        c4dp = c4d
                        c3dp = c3d
                        o3dp = o3d
                        p = []
                        o5d = []
                        c5d = [] 
                        c4d = []
                        o4d = []
                        c3d = []
                        o3d = []
                        c2d = []
                        o2d = []
                        c1d = []
                        oh = []
                        n9 = []
                        c8 = []
                        c6 = []
                        n6 = []
                        n1 = []
                        nh = []
                        c2 = []
                        n2 = [] 
                        n3 = []
                        c4 = []
                        n4 = []                     
                    except:
                        continue


flist = os.listdir("C:/SSCRview/PDB_MMCIF_GZ")

for i, pdb_file_gz in enumerate(flist):
    os.chdir("C:/SSCRview/PDB_MMCIF_GZ")
    pdb_file = _open(pdb_file_gz)
    for model in Bio.PDB.FastMMCIFParser().get_structure("RNA", pdb_file) :
        for chain in model :
            full_id=model.get_full_id()
            #mname = pdb_file[-8:-4]
            mname = pdb_file_gz[:-7]
            fname = "C:/SSCRview/SSCR_ssc_data/%s_Model_%s_Chain_%s.txt" % (str(mname), str(model.id), str(chain.id))
            residue_nump = 0
            for residue_index, residue in enumerate(chain) :
                residue_id = residue.id
                residue_num = residue_id[1]
                residue_name = residue.resname
                if residue_name == "A" or residue_name == "G" or residue_name == "C" or residue_name == "U" :
                    if residue_index == 0:
                        ppl=[]
                        fc = open(str(fname), 'a')
                        fc.write('')
                        mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                        mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                        mname3 = "length %i " % (len(residue))
                        fc.write('\n')
                        fc.close()
                        residue_nump = residue_num
                        # A
                        if residue_name == "A" :
                            n1 = []
                            try:
                                n1 = residue["N1"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n3 = []
                                    if residue_name2 == "U" :
                                        try:
                                            n3 = residue2["N3"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n1 - n3
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            if ess == "S" :
                                fc.write(ess)
                                fc.close()
                            else:
                                fc.write("N")
                                fc.close()
                            
                        # G
                        elif residue_name == "G" :
                            n1 = []
                            try:
                                n1 = residue["N1"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n3 =[]
                                    if residue_name2 == "C" :
                                        try:
                                            n3 = residue2["N3"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n1 - n3
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            if ess == "S" :
                                fc.write(ess)
                                fc.close()
                            else:
                                fc.write("N")
                                fc.close()
                        # C
                        elif residue_name == "C" :
                            n3 = []
                            try:
                                n3 = residue["N3"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n1 = []
                                    if residue_name2 == "G" :
                                        try:
                                            n1 = residue2["N1"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n3 - n1
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            if ess == "S" :
                                fc.write(ess)
                                fc.close()
                            else:
                                fc.write("N")
                                fc.close()
                        # U
                        elif residue_name == "U" :
                            n3 = []
                            try:
                                n3 = residue["N3"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n1 = []
                                    if residue_name2 == "A" :
                                        try:
                                            n1 = residue2["N1"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n3 - n1
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            if ess == "S" :
                                fc.write(ess)
                                fc.close()
                            else:
                                fc.write("N")
                                fc.close()
                        else:
                            continue
                    else:
                        ppl=[]
                        fc = open(str(fname), 'a')
                        fc.write('')
                        mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                        mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                        mname3 = "length %i " % (len(residue))
                        if residue_index > 0:
                            if residue_num != residue_nump + 1:
                                fc.write("D")
                        fc.close()
                        residue_nump = residue_num
                        # A
                        if residue_name == "A" :
                            n1 = []
                            try:
                                n1 = residue["N1"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n3 = []
                                    if residue_name2 == "U" :
                                        try:
                                            n3 = residue2["N3"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n1 - n3
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            if ess == "S" :
                                fc.write(ess)
                                fc.close()
                            else:
                                fc.write("N")
                                fc.close()
                        # G
                        elif residue_name == "G" :
                            n1 = []
                            try:
                                n1 = residue["N1"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n3 =[]
                                    if residue_name2 == "C" :
                                        try:
                                            n3 = residue2["N3"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n1 - n3
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            if ess == "S" :
                                fc.write(ess)
                                fc.close()
                            else:
                                fc.write("N")
                                fc.close()
                        # C
                        elif residue_name == "C" :
                            n3 = []
                            try:
                                n3 = residue["N3"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n1 = []
                                    if residue_name2 == "G" :
                                        try:
                                            n1 = residue2["N1"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n3 - n1
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            if ess == "S" :
                                fc.write(ess)
                                fc.close()
                            else:
                                fc.write("N")
                                fc.close()
                        # U
                        elif residue_name == "U" :
                            n3 = []
                            try:
                                n3 = residue["N3"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n1 = []
                                    if residue_name2 == "A" :
                                        try:
                                            n1 = residue2["N1"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n3 - n1
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            if ess == "S" :
                                fc.write(ess)
                                fc.close()
                            else:
                                fc.write("N")
                                fc.close()
                        else:
                            continue
                else:
                    if residue_index == 0:
                        #break
                        fc = open(str(fname), 'a')
                        fc.write('')
                        mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                        mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                        mname3 = "length %i " % (len(residue))
                        #fc.write(str(mname1))
                        fc.write('\n')
                        fc.close()

flist = os.listdir("C:/SSCRview/SSCR_ssc_data")

os.chdir("C:/SSCRview/SSCR_ssc_data")
for i, line in enumerate(flist):
    fa = open(str(line), 'r')
    dataa1 = fa.readlines()
    fa.close()
    if str(dataa1[1]) == "\n":
        os.remove(str(str(line)))

flist = os.listdir("C:/SSCRview/PDB_MMCIF_GZ")

for i, pdb_file_gz in enumerate(flist):
    os.chdir("C:/SSCRview/PDB_MMCIF_GZ")
    pdb_file = _open(pdb_file_gz)
    for model in Bio.PDB.FastMMCIFParser().get_structure("RNA", pdb_file) :
        for chain in model :
            full_id=model.get_full_id()
            #mname = pdb_file[-8:-4]
            mname = pdb_file_gz[:-7]
            fname = "C:/SSCRview/SeqSSR_data/%s_Model_%s_Chain_%s_SeqSSR.txt" % (str(mname), str(model.id), str(chain.id))
            residue_nump = 0
            for residue_index, residue in enumerate(chain) :
                residue_id = residue.id
                residue_num = residue_id[1]
                residue_name = residue.resname
                if residue_name == "A" or residue_name == "G" or residue_name == "C" or residue_name == "U" :
                    if residue_index == 0:
                        ppl=[]
                        fc = open(str(fname), 'w')
                        fc.write('')
                        mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                        mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                        mname3 = "length %i " % (len(residue))
                        fc.write(str(mname1))
                        fc.write('\n')
                        fc.close()
                        residue_nump = residue_num
                        # A
                        if residue_name == "A" :
                            n1 = []
                            try:
                                n1 = residue["N1"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n3 = []
                                    if residue_name2 == "U" :
                                        try:
                                            n3 = residue2["N3"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n1 - n3
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            if ess == "S" :
                                fc.write('\t')
                                fc.write(ess)
                                fc.write('\t')
                                fc.write(chainid_name2)
                                fc.write('\t')
                                fc.write(resi_name2)
                                fc.write('\t')
                                fc.write(resi_num2)
                                fc.write('\n')
                                fc.close()
                            else:
                                fc.write('\t')
                                fc.write("N")
                                fc.write('\n')
                                fc.close()
                        # G
                        elif residue_name == "G" :
                            n1 = []
                            try:
                                n1 = residue["N1"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n3 = []
                                    if residue_name2 == "C" :
                                        try:
                                            n3 = residue2["N3"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n1 - n3
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            if ess == "S" :
                                fc.write('\t')
                                fc.write(ess)
                                fc.write('\t')
                                fc.write(chainid_name2)
                                fc.write('\t')
                                fc.write(resi_name2)
                                fc.write('\t')
                                fc.write(resi_num2)
                                fc.write('\n')
                                fc.close()
                            else:
                                fc.write('\t')
                                fc.write("N")
                                fc.write('\n')
                                fc.close()
                        # C
                        elif residue_name == "C" :
                            n3 = []
                            try:
                                n3 = residue["N3"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n1 = []
                                    if residue_name2 == "G" :
                                        try:
                                            n1 = residue2["N1"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n3 - n1
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            if ess == "S" :
                                fc.write('\t')
                                fc.write(ess)
                                fc.write('\t')
                                fc.write(chainid_name2)
                                fc.write('\t')
                                fc.write(resi_name2)
                                fc.write('\t')
                                fc.write(resi_num2)
                                fc.write('\n')
                                fc.close()
                            else:
                                fc.write('\t')
                                fc.write("N")
                                fc.write('\n')
                                fc.close()
                        # U
                        elif residue_name == "U" :
                            n3 = []
                            try:
                                n3 = residue["N3"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n1 = []
                                    if residue_name2 == "A" :
                                        try:
                                            n1 = residue2["N1"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n3 - n1
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            if ess == "S" :
                                fc.write('\t')
                                fc.write(ess)
                                fc.write('\t')
                                fc.write(chainid_name2)
                                fc.write('\t')
                                fc.write(resi_name2)
                                fc.write('\t')
                                fc.write(resi_num2)
                                fc.write('\n')
                                fc.close()
                            else:
                                fc.write('\t')
                                fc.write("N")
                                fc.write('\n')
                                fc.close()
                        else:
                            continue
                    else:
                        ppl=[]
                        fc = open(str(fname), 'a')
                        fc.write('')
                        mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                        mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                        mname3 = "length %i " % (len(residue))
                        if residue_index > 0:
                            if residue_num != residue_nump + 1:
                                fc.write("X")
                                fc.write('\n')
                        fc.close()
                        residue_nump = residue_num
                        # A
                        if residue_name == "A" :
                            n1 = []
                            try:
                                n1 = residue["N1"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n3 = []
                                    if residue_name2 == "U" :
                                        try:
                                            n3 = residue2["N3"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n1 - n3
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            if ess == "S" :
                                fc.write('\t')
                                fc.write(ess)
                                fc.write('\t')
                                fc.write(chainid_name2)
                                fc.write('\t')
                                fc.write(resi_name2)
                                fc.write('\t')
                                fc.write(resi_num2)
                                fc.write('\n')
                                fc.close()
                            else:
                                fc.write('\t')
                                fc.write("N")
                                fc.write('\n')
                                fc.close()
                        # G
                        elif residue_name == "G" :
                            n1 = []
                            try:
                                n1 = residue["N1"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n3 = []
                                    if residue_name2 == "C" :
                                        try:
                                            n3 = residue2["N3"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n1 - n3
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            if ess == "S" :
                                fc.write('\t')
                                fc.write(ess)
                                fc.write('\t')
                                fc.write(chainid_name2)
                                fc.write('\t')
                                fc.write(resi_name2)
                                fc.write('\t')
                                fc.write(resi_num2)
                                fc.write('\n')
                                fc.close()
                            else:
                                fc.write('\t')
                                fc.write("N")
                                fc.write('\n')
                                fc.close()
                        # C
                        elif residue_name == "C" :
                            n3 = []
                            try:
                                n3 = residue["N3"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n1 = []
                                    if residue_name2 == "G" :
                                        try:
                                            n1 = residue2["N1"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n3 - n1
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            if ess == "S" :
                                fc.write('\t')
                                fc.write(ess)
                                fc.write('\t')
                                fc.write(chainid_name2)
                                fc.write('\t')
                                fc.write(resi_name2)
                                fc.write('\t')
                                fc.write(resi_num2)
                                fc.write('\n')
                                fc.close()
                            else:
                                fc.write('\t')
                                fc.write("N")
                                fc.write('\n')
                                fc.close()
                        # U
                        elif residue_name == "U" :
                            n3 = []
                            try:
                                n3 = residue["N3"]
                            except:
                                ess = "D"
                            ess = []
                            chainid3 = [] 
                            residue_num3 = 0
                            residue_name3 = []
                            for chain2 in model :
                                chainid2 = chain2.id
                                for residue_index2, residue2 in enumerate(chain2) :
                                    residue_id2 = residue2.id
                                    residue_num2 = residue_id2[1]
                                    residue_name2 = residue2.resname
                                    n1 = []
                                    if residue_name2 == "A" :
                                        try:
                                            n1 = residue2["N1"]
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            dis = n3 - n1
                                        except:
                                            #ess = "D"
                                            continue
                                        try:
                                            if dis < 3.5 :
                                                residue_num2_p = residue_num2 - 1
                                                residue_num2_n = residue_num2 + 1
                                                if residue_num == residue_num2_p or residue_num == residue_num2_n :
                                                    if chain.id == chainid2:
                                                        continue
                                                    else:
                                                        ess = "S"
                                                        chainid3 = chainid2 
                                                        residue_num3 = residue_num2
                                                        residue_name3 = residue_name2                                                           
                                                else:
                                                    ess = "S"
                                                    chainid3 = chainid2 
                                                    residue_num3 = residue_num2
                                                    residue_name3 = residue_name2   
                                            else:
                                                continue
                                        except:
                                            continue
                                    else:
                                        continue                                   
                            resi_name = "%s" % (residue_name)
                            resi_num = "%i" % (residue_num)
                            chainid_name2 = "%s" % (chainid3)
                            resi_name2 = "%s" % (residue_name3)
                            resi_num2 = "%i" % (residue_num3)
                            fc = open(str(fname), 'a')
                            fc.write('')
                            fc.write(resi_name)
                            fc.write('\t')
                            fc.write(resi_num)
                            if ess == "S" :
                                fc.write('\t')
                                fc.write(ess)
                                fc.write('\t')
                                fc.write(chainid_name2)
                                fc.write('\t')
                                fc.write(resi_name2)
                                fc.write('\t')
                                fc.write(resi_num2)
                                fc.write('\n')
                                fc.close()
                            else:
                                fc.write('\t')
                                fc.write("N")
                                fc.write('\n')
                                fc.close()
                        else:
                            continue
                else:
                    if residue_index == 0:
                        #break
                        fc = open(str(fname), 'w')
                        fc.write('')
                        mname1 = ">%s_Model_%s_Chain_%s " % (str(mname), str(model.id), str(chain.id))
                        mname2 = "(part %i of %i) " % (residue_index+1, len(chain))
                        mname3 = "length %i " % (len(residue))
                        fc.write(str(mname1))
                        fc.write('\n')
                        fc.close()

flist = os.listdir("C:/SSCRview/SeqSSR_data")

os.chdir("C:/SSCRview/SeqSSR_data")
for i, line in enumerate(flist):
    fa = open(str(line), 'r')
    dataa1 = fa.readlines()
    fa.close()
    try:
        dataa1[1]
    except:
        os.remove(str(str(line)))
                


